From 407ba1849f7dc6744b74746c3325a392ba4ab42f Mon Sep 17 00:00:00 2001
From: Andrew Price <andrewprice@andrewalexanderprice.com>
Date: Fri, 26 Aug 2011 14:35:17 +0930
Subject: [PATCH 4/8] many changes

---
 modules/video_filter/stereoscopy.c        | 1547 ++++++++++++++++++++++++-----
 modules/video_filter/stereoscopycombine.c |  816 +++++++++++++++
 modules/video_output/msw/nvapi.c          |  236 +++++
 modules/video_output/msw/nvapi.h          |  167 ++++
 nvapiwrapper/README                       |    7 -
 nvapiwrapper/nvapi.lib                    |  Bin 81968 -> 0 bytes
 nvapiwrapper/nvapiwrapper.c               |   41 -
 nvapiwrapper/nvapiwrapper.dll             |  Bin 49152 -> 0 bytes
 8 files changed, 2514 insertions(+), 300 deletions(-)
 create mode 100644 modules/video_filter/stereoscopycombine.c
 create mode 100644 modules/video_output/msw/nvapi.c
 create mode 100644 modules/video_output/msw/nvapi.h
 delete mode 100644 nvapiwrapper/README
 delete mode 100644 nvapiwrapper/nvapi.lib
 delete mode 100644 nvapiwrapper/nvapiwrapper.c
 delete mode 100644 nvapiwrapper/nvapiwrapper.dll

diff --git a/modules/video_filter/stereoscopy.c b/modules/video_filter/stereoscopy.c
index cd96e81..fc9c4a0 100644
--- a/modules/video_filter/stereoscopy.c
+++ b/modules/video_filter/stereoscopy.c
@@ -1,5 +1,5 @@
 /*****************************************************************************
- * stereoscopy.c : "steroscopy" video filter - splits one image into 2 eyes
+ * stereoscopy.c : "sterosecopy" video filter - splits one image into 2 eyes
  *****************************************************************************
  * Copyright (C) 2011 the VideoLAN team
  *
@@ -36,6 +36,8 @@
 #include "filter_picture.h"
 #include "stereoscopy.h"
 
+#include <vlc_fixups.h>
+
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
@@ -43,127 +45,193 @@ static int  Create    ( vlc_object_t * );
 static picture_t *Filter( filter_t *, picture_t * );
 static void Destroy( vlc_object_t *p_this );
 
+static int InputModeStrToValue(const char *str);
+static int InputModeChangedCallback( vlc_object_t *p_this, char const *psz_name,
+                               vlc_value_t newval, vlc_value_t oldval, void *p_unused );
+
 /* based on those from extract.c */
-static void get_red_from_yuv420( picture_t *, picture_t *, int, int, int );
-static void get_red_from_yuv422( picture_t *, picture_t *, int, int, int );
-static void get_cyan_from_yuv420( picture_t *, picture_t *, int, int, int );
-static void get_cyan_from_yuv422( picture_t *, picture_t *, int, int, int );
-static void get_green_from_yuv420( picture_t *, picture_t *, int, int, int );
-static void get_green_from_yuv422( picture_t *, picture_t *, int, int, int );
-static void get_magenta_from_yuv420( picture_t *, picture_t *, int, int, int );
-static void get_magenta_from_yuv422( picture_t *, picture_t *, int, int, int );
-static void get_blue_from_yuv420( picture_t *, picture_t *, int, int, int );
-static void get_blue_from_yuv422( picture_t *, picture_t *, int, int, int );
-static void get_yellow_from_yuv420( picture_t *, picture_t *, int, int, int );
-static void get_yellow_from_yuv422( picture_t *, picture_t *, int, int, int );
-
-static void get_red_grayscale_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_red_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_red_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_red_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_red_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_cyan_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_cyan_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_cyan_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_cyan_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_green_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_green_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_green_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_green_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_magenta_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_magenta_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_magenta_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_magenta_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_blue_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_blue_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_blue_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_blue_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_yellow_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_yellow_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_yellow_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+static void get_yellow_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int, int );
+
+static void get_red_grayscale_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_red_grayscale_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_red_grayscale_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_red_grayscale_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_red_grayscale_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_cyan_grayscale_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_cyan_grayscale_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_cyan_grayscale_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_cyan_grayscale_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_cyan_grayscale_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_green_grayscale_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_cyan_grayscale_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_green_grayscale_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_green_grayscale_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_magenta_grayscale_from_yuv420( picture_t *, picture_t *, int,
+static void get_green_grayscale_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_green_grayscale_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_green_grayscale_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_magenta_grayscale_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int,
+    int, int );
+static void get_magenta_grayscale_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int,
+    int, int );
+static void get_magenta_grayscale_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int,
     int, int );
-static void get_magenta_grayscale_from_yuv422( picture_t *, picture_t *, int,
+static void get_magenta_grayscale_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int,
     int, int );
-static void get_blue_grayscale_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_blue_grayscale_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_blue_grayscale_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_blue_grayscale_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
     int );
-static void get_yellow_grayscale_from_yuv420( picture_t *, picture_t *, int,
+static void get_blue_grayscale_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_blue_grayscale_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
+    int );
+static void get_yellow_grayscale_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int,
+    int, int );
+static void get_yellow_grayscale_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int,
     int, int );
-static void get_yellow_grayscale_from_yuv422( picture_t *, picture_t *, int,
+static void get_yellow_grayscale_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int,
+    int, int );
+static void get_yellow_grayscale_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int,
     int, int );
 
-static void get_cyan_fill_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_cyan_fill_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
+   int );
+static void get_cyan_fill_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
    int );
-static void get_cyan_fill_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_cyan_fill_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
    int );
-static void get_magenta_fill_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_cyan_fill_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
    int );
-static void get_magenta_fill_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_magenta_fill_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
    int );
-static void get_yellow_fill_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_magenta_fill_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
    int );
-static void get_yellow_fill_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_magenta_fill_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
+   int );
+static void get_magenta_fill_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
+   int );
+static void get_yellow_fill_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
+   int );
+static void get_yellow_fill_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
+   int );
+static void get_yellow_fill_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_yellow_fill_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
 
-static void get_lefthalf_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_lefthalf_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
-static void get_lefthalf_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_lefthalf_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
-static void get_righthalf_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_lefthalf_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
-static void get_righthalf_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_lefthalf_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
-static void get_tophalf_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_righthalf_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
-static void get_tophalf_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_righthalf_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
-static void get_bottomhalf_from_yuv420( picture_t *, picture_t *, int, int,
+static void get_righthalf_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
-static void get_bottomhalf_from_yuv422( picture_t *, picture_t *, int, int,
+static void get_righthalf_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_tophalf_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_tophalf_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_tophalf_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_tophalf_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_bottomhalf_from_yuv411( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_bottomhalf_from_yuv420( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_bottomhalf_from_yuv422( filter_t *p_filter, picture_t *, picture_t *, int, int,
+  int );
+static void get_bottomhalf_from_yuv444( filter_t *p_filter, picture_t *, picture_t *, int, int,
   int );
 
-#define FILTER_PREFIX "stereoscopy-"
+#define FILTER_PREFIX "stereoscopic-"
 
 #define LEFT_EYE_METHOD_TEXT N_("Left eye stereoscopy encoding")
 #define RIGHT_EYE_METHOD_TEXT N_("Right eye stereoscopy enconding")
 #define LEFT_EYE_METHOD_LONGTEXT N_("Represents the form of steroscopic "\
                                     "encoding used for the image of the "\
                                     "respective eye. " \
-                                    "0 - The image is intended to be 2D " \
-                                    "and should be displayed as such. " \
-                                    "1000 - The eye is encoded in the " \
+                                    "blue - The eye is encoded in the " \
                                     "blue channel. " \
-                                    "1001 - The eye is encoded in the " \
+                                    "magenta - The eye is encoded in the " \
                                     "green and blue channels. " \
-                                    "1002 - The eye is encoded in the " \
+                                    "green - The eye is encoded in the " \
                                     "green channel. " \
-                                    "1003 - The eye is encoded in the " \
+                                    "cyan - The eye is encoded in the " \
                                     "red and blue channels. " \
-                                    "1004 - The eye is encoded in the " \
+                                    "red - The eye is encoded in the " \
                                     "red channel. " \
-                                    "1005 - The eye is encoded in the " \
+                                    "yellow - The eye is encoded in the " \
                                     "red and green channels. " \
-                                    "1010 - The eye is encoded in the " \
+                                    "blue-gray - The eye is encoded in the " \
                                     "blue channel as a gray scale image. " \
-                                    "1011 - The eye is encoded in the " \
+                                    "cyan-gray - The eye is encoded in the " \
                                     "green and blue channels as a gray " \
                                     "scale image. " \
-                                    "1012 - The eye is encoded in the " \
+                                    "green-gray - The eye is encoded in the " \
                                     "green channel as a gray scale image. " \
-                                    "1013 - The eye is encoded in the " \
+                                    "magenta-gray - The eye is encoded in the " \
                                     "red and blue channels as a gray " \
                                     "scale image. " \
-                                    "1014 - The eye is encoded in the " \
+                                    "red-gray - The eye is encoded in the " \
                                     "red channel as a gray scale image. " \
-                                    "1015 - The eye is encoded in the " \
+                                    "yellow-gray - The eye is encoded in the " \
                                     "red and green channels as a gray " \
                                     "scale image. " \
-                                    "1021 - The eye is encoded in the " \
+                                    "cyan-fill - The eye is encoded in the " \
                                     "green and blue channels interpolating" \
                                     "the red channel. " \
-                                    "1023 - The eye is encoded in the " \
+                                    "magenta-fill - The eye is encoded in the " \
                                     "red and blue channels interpolating" \
                                     "the green channel. " \
-                                    "1025 - The eye is encoded in the " \
+                                    "blue-fill - The eye is encoded in the " \
                                     "red and green channels interpolating" \
                                     "the blue channel. " \
-                                    "2000 - The eye is encoded in the " \
+                                    "left - The eye is encoded in the " \
                                     "left half of the image. " \
-                                    "2001 - The eye is encoded in the " \
+                                    "right - The eye is encoded in the " \
                                     "right half of the image. " \
-                                    "2002 - The eye is encoded in the " \
+                                    "bottom - The eye is encoded in the " \
                                     "bottom half of the image. " \
-                                    "2003 - The eye is encoded in the " \
+                                    "top - The eye is encoded in the " \
                                     "top half of the image. ")
 #define RIGHT_EYE_METHOD_LONGTEXT LEFT_EYE_METHOD_LONGTEXT
 
@@ -172,8 +240,24 @@ struct filter_sys_t
     int    i_leftEyeMethod;      /* stereoscopy encoding for left eye */
     int    i_rightEyeMethod;     /* stereoscopy encoding for right eye */
     bool   b_leftEyeLast;
+	mtime_t i_lastTime;          /* time of previous frame */
 };
 
+static const char * const type_list_text[] = { N_("Blue (Anaglyph)"),
+	N_("Cyan (Anaglyph)"), N_("Green (Anaglyph)"), N_("Magenta (Anaglyph)"),
+    N_("Red (Anaglyph)"), N_("Yellow (Anaglyph)"), N_("Blue (Grayscale Anaglyph)"),
+    N_("Cyan (Grayscale Anaglyph)"), N_("Green (Grayscale Anaglyph)"),
+    N_("Magenta (Grayscale Anaglyph)"), N_("Red (Grayscale Anaglyph)"),
+    N_("Yellow (Grayscale Anaglyph)"), N_("Cyan (Fill Anaglyph)"),
+    N_("Magenta (Fill Anaglyph)"), N_("Yellow (Fill Anaglyph)"),
+    N_("Left half (Side by Side)"), N_("Right half (Side by Side)"),
+    N_("Bottom half (Side by Side)"), N_("Top half (Side by Side)") };
+
+static const char * const type_list[] = { "blue", "cyan", "green",
+	"magenta", "red", "yellow", "blue-gray", "cyan-gray", "green-gray",
+	"magenta-gray", "red-gray", "yellow-gray", "cyan-fill", "magenta-fill",
+	"yellow-fill", "left", "right", "bottom", "top"};
+
 /*****************************************************************************
  * Module descriptor
  *****************************************************************************/
@@ -183,14 +267,19 @@ vlc_module_begin ()
     set_capability( "video filter2", 0 )
     set_category( CAT_VIDEO )
     set_subcategory( SUBCAT_VIDEO_VFILTER )
+	
+    add_string(FILTER_PREFIX "left", "left", LEFT_EYE_METHOD_TEXT, LEFT_EYE_METHOD_LONGTEXT, false)
+        change_string_list(type_list, type_list_text, 0)
+	add_string(FILTER_PREFIX "right", "right", RIGHT_EYE_METHOD_TEXT, RIGHT_EYE_METHOD_LONGTEXT, false)
+        change_string_list(type_list, type_list_text, 0)
 
     add_shortcut( "stereoscopy" )
     set_callbacks( Create, Destroy )
 
-    add_integer( FILTER_PREFIX "left", STEREOSCOPY_ANAGLYPH_RED,
+    /* add_integer( FILTER_PREFIX "left", STEREOSCOPY_ANAGLYPH_RED,
                  LEFT_EYE_METHOD_TEXT, LEFT_EYE_METHOD_LONGTEXT, false )
     add_integer( FILTER_PREFIX "right", STEREOSCOPY_ANAGLYPH_CYAN,
-                 RIGHT_EYE_METHOD_TEXT, RIGHT_EYE_METHOD_LONGTEXT, false )
+                 RIGHT_EYE_METHOD_TEXT, RIGHT_EYE_METHOD_LONGTEXT, false )*/
 vlc_module_end ()
 
 /*****************************************************************************
@@ -202,6 +291,7 @@ static int Create( vlc_object_t *p_this )
 {
     filter_t *p_filter;
     filter_sys_t *p_sys;
+    char *eyeMethod;
 
     p_filter = (filter_t *)p_this;
     p_filter->pf_video_filter = Filter;
@@ -210,15 +300,37 @@ static int Create( vlc_object_t *p_this )
     if( !p_sys )
         return VLC_ENOMEM;
 
-    p_sys->i_leftEyeMethod = var_InheritInteger( p_filter,
-        FILTER_PREFIX "left" );
-    p_sys->i_rightEyeMethod = var_InheritInteger( p_filter,
-        FILTER_PREFIX "right" );
+	/* read in method for left eye */
+	eyeMethod = var_InheritString( p_filter, FILTER_PREFIX "left" );
+	if( eyeMethod )
+	{
+		p_sys->i_leftEyeMethod = InputModeStrToValue(eyeMethod);
+		free(eyeMethod);
+	}
+	else
+	{
+		p_sys->i_leftEyeMethod = STEREOSCOPY_SIDEBYSIDE_LEFT;
+	}
+
+	/* read in method for right eye */
+	eyeMethod = var_InheritString( p_filter, FILTER_PREFIX "right" );
+	if( eyeMethod )
+	{
+		p_sys->i_rightEyeMethod = InputModeStrToValue(eyeMethod);
+		free(eyeMethod);
+	}
+	else
+	{
+		p_sys->i_rightEyeMethod = STEREOSCOPY_SIDEBYSIDE_RIGHT;
+	}
+
     p_sys->b_leftEyeLast = false;
+	p_sys->i_lastTime = 0;
 
-    return VLC_SUCCESS;
+	return VLC_SUCCESS;
 }
 
+
 /*****************************************************************************
  * Destroy: destroy Crop video thread output method
  *****************************************************************************
@@ -227,18 +339,103 @@ static int Create( vlc_object_t *p_this )
 static void Destroy( vlc_object_t *p_this )
 {
     filter_t *p_filter = (filter_t*)p_this;
+
     free( p_filter->p_sys );
+	p_filter->p_sys = NULL;
+}
+
+/*****************************************************************************
+ * InputModeStrToValue: input mode string to value method
+ *****************************************************************************
+ * Converts the string of an input mode (e.g. "left") to it's value
+ * (e.g. STEREOSCOPY_SIDEBYSIDE_LEFT).
+ *****************************************************************************/
+static int InputModeStrToValue(const char *str) {
+    if(strcmp(str, "blue") == 0)
+        return STEREOSCOPY_ANAGLYPH_BLUE;
+    if(strcmp(str, "cyan") == 0)
+        return STEREOSCOPY_ANAGLYPH_CYAN;
+    if(strcmp(str, "green") == 0)
+        return STEREOSCOPY_ANAGLYPH_GREEN;
+    if(strcmp(str, "magenta") == 0)
+        return STEREOSCOPY_ANAGLYPH_MAGENTA;
+    if(strcmp(str, "red") == 0)
+        return STEREOSCOPY_ANAGLYPH_RED;
+    if(strcmp(str, "yellow") == 0)
+        return STEREOSCOPY_ANAGLYPH_YELLOW;
+    if(strcmp(str, "blue-gray") == 0)
+        return STEREOSCOPY_ANAGLYPH_BLUE_GRAY;
+    if(strcmp(str, "cyan-gray") == 0)
+        return STEREOSCOPY_ANAGLYPH_CYAN_GRAY;
+    if(strcmp(str, "green-gray") == 0)
+        return STEREOSCOPY_ANAGLYPH_GREEN_GRAY;
+    if(strcmp(str, "magenta-gray") == 0)
+        return STEREOSCOPY_ANAGLYPH_MAGENTA_GRAY;
+    if(strcmp(str, "red-gray") == 0)
+        return STEREOSCOPY_ANAGLYPH_RED_GRAY;
+    if(strcmp(str, "yellow-gray") == 0)
+        return STEREOSCOPY_ANAGLYPH_YELLOW_GRAY;
+    if(strcmp(str, "cyan-fill") == 0)
+        return STEREOSCOPY_ANAGLYPH_CYAN_FILL;
+    if(strcmp(str, "magenta-fill") == 0)
+        return STEREOSCOPY_ANAGLYPH_MAGENTA_FILL;
+    if(strcmp(str, "yellow-fill") == 0)
+        return STEREOSCOPY_ANAGLYPH_YELLOW_FILL;
+    if(strcmp(str, "left") == 0)
+        return STEREOSCOPY_SIDEBYSIDE_LEFT;
+    if(strcmp(str, "right") == 0)
+        return STEREOSCOPY_SIDEBYSIDE_RIGHT;
+    if(strcmp(str, "bottom") == 0)
+        return STEREOSCOPY_SIDEBYSIDE_BOTTOM;
+    if(strcmp(str, "top") == 0)
+        return STEREOSCOPY_SIDEBYSIDE_TOP;
+
+    /* nothing left */
+    return STEREOSCOPY_2D;
+}
+
+/*****************************************************************************
+ * InputModeChangedCallback: handles the input mode changing
+ *****************************************************************************
+ * Handles switching between input modes during playback.
+ *****************************************************************************/
+static int InputModeChangedCallback( vlc_object_t *p_this, char const *psz_name,
+                               vlc_value_t newval, vlc_value_t oldval, void *p_unused )
+{
+    VLC_UNUSED(psz_name);
+    VLC_UNUSED(newval);
+    VLC_UNUSED(oldval);
+    VLC_UNUSED(p_unused);
+
+	filter_t *p_filter;
+    filter_sys_t *p_sys;
+    char *eyeMethod;
+
+    p_filter = (filter_t *)p_this;
+    p_sys = p_filter->p_sys;
+
+	/* read in method for left eye */
+	eyeMethod = var_InheritString( p_filter, FILTER_PREFIX "left" );
+	p_sys->i_leftEyeMethod = InputModeStrToValue(eyeMethod);
+	free(eyeMethod);
+
+	/* read in method for right eye */
+	eyeMethod = var_InheritString( p_filter, FILTER_PREFIX "right" );
+	p_sys->i_rightEyeMethod = InputModeStrToValue(eyeMethod);
+	free(eyeMethod);
+
+    return VLC_SUCCESS;
 }
 
 
 /*****************************************************************************
- * DecodeImageYUV: extracts an image from a greater RGB image
+ * DecodeImageYUV: extracts an image from a greater yuv image
  *****************************************************************************
  * Extracts the image for a single eye from a stereoscopic image containing
- * both eyes in YUV420 or YUV422 format.
+ * both eyes.
  *****************************************************************************/
 static picture_t *DecodeImageYUV( filter_t *p_filter, picture_t *p_inpic,
-    int i_method, bool yuv422)
+    int i_method, int chromaformat)
 {
     picture_t *p_output = filter_NewPicture( p_filter );
 
@@ -248,156 +445,403 @@ static picture_t *DecodeImageYUV( filter_t *p_filter, picture_t *p_inpic,
     switch( i_method) 
     {
         case STEREOSCOPY_ANAGLYPH_BLUE:
-            if(yuv422)
-                get_blue_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_blue_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_blue_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_blue_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_blue_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_blue_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_CYAN:
-            if(yuv422)
-                get_cyan_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_cyan_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_cyan_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_cyan_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_cyan_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_cyan_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_GREEN:
-            if(yuv422)
-                get_green_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_green_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_green_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_green_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_green_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_green_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_MAGENTA:
-            if(yuv422)
-                get_magenta_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_magenta_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_magenta_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_magenta_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_magenta_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_magenta_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_RED:
-            if(yuv422)
-                get_red_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_red_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_red_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_red_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_red_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_red_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_YELLOW:
-            if(yuv422)
-                get_yellow_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_yellow_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_yellow_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_yellow_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_yellow_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_yellow_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_BLUE_GRAY:
-            if(yuv422)
-                get_blue_grayscale_from_yuv422(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_blue_grayscale_from_yuv420(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_blue_grayscale_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_blue_grayscale_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_blue_grayscale_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_blue_grayscale_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_CYAN_GRAY:
-            if(yuv422)
-                get_cyan_grayscale_from_yuv422(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_cyan_grayscale_from_yuv420(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_cyan_grayscale_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_cyan_grayscale_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_cyan_grayscale_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_cyan_grayscale_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_GREEN_GRAY:
-            if(yuv422)
-                get_green_grayscale_from_yuv422(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_green_grayscale_from_yuv420(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_green_grayscale_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_green_grayscale_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_green_grayscale_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_green_grayscale_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_MAGENTA_GRAY:
-            if(yuv422)
-                get_magenta_grayscale_from_yuv422(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_magenta_grayscale_from_yuv420(p_inpic,
-                    p_output, Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_magenta_grayscale_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_magenta_grayscale_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_magenta_grayscale_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_magenta_grayscale_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_RED_GRAY:
-            if(yuv422)
-                get_red_grayscale_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_red_grayscale_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_red_grayscale_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_red_grayscale_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_red_grayscale_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_red_grayscale_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_YELLOW_GRAY:
-            if(yuv422)
-                get_yellow_grayscale_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_yellow_grayscale_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_yellow_grayscale_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_yellow_grayscale_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_yellow_grayscale_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_yellow_grayscale_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_CYAN_FILL:
-            if(yuv422)
-                get_cyan_fill_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_cyan_fill_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_cyan_fill_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_cyan_fill_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_cyan_fill_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_cyan_fill_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_MAGENTA_FILL:
-            if(yuv422)
-                get_magenta_fill_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_magenta_fill_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_magenta_fill_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_magenta_fill_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_magenta_fill_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_magenta_fill_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_ANAGLYPH_YELLOW_FILL:
-            if(yuv422)
-                get_yellow_fill_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_yellow_fill_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_yellow_fill_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_yellow_fill_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_yellow_fill_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_yellow_fill_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_SIDEBYSIDE_LEFT:
-            if(yuv422)
-                get_lefthalf_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_lefthalf_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_lefthalf_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_lefthalf_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_lefthalf_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_lefthalf_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_SIDEBYSIDE_RIGHT:
-            if(yuv422)
-                get_righthalf_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_righthalf_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_righthalf_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_righthalf_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_righthalf_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_righthalf_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_SIDEBYSIDE_BOTTOM:
-            if(yuv422)
-                get_bottomhalf_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_bottomhalf_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_bottomhalf_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_bottomhalf_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_bottomhalf_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_bottomhalf_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
         case STEREOSCOPY_SIDEBYSIDE_TOP:
-            if(yuv422)
-                get_tophalf_from_yuv422(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
-            else
-                get_tophalf_from_yuv420(p_inpic, p_output,
-                    Y_PLANE, U_PLANE, V_PLANE);
+            switch(chromaformat)
+            {
+                case 411:
+                    get_tophalf_from_yuv411(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 420:
+                    get_tophalf_from_yuv420(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 422:
+                    get_tophalf_from_yuv422(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+                case 444:
+                    get_tophalf_from_yuv444(p_filter, p_inpic, p_output,
+                        Y_PLANE, U_PLANE, V_PLANE);
+                    break;
+            }
             break;
     }
 
@@ -414,7 +858,7 @@ static picture_t *DecodeImageYUV( filter_t *p_filter, picture_t *p_inpic,
 static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
 {
     filter_sys_t *p_sys;
-    bool yuv422;
+    int chromaformat;
 
     if( !p_inpic ) return NULL;
 
@@ -434,27 +878,39 @@ static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
         return p_inpic;
     switch( p_inpic->format.i_chroma )
     {
+        case VLC_CODEC_I411:
+            chromaformat = 411;
+            break;
         case VLC_CODEC_I420:
         case VLC_CODEC_J420:
-        case VLC_CODEC_YV12:
-            yuv422 = false;
+            chromaformat = 420;
             break;
+        case VLC_CODEC_YV12:
         case VLC_CODEC_I422:
         case VLC_CODEC_J422:
-            yuv422 = true;
+            chromaformat = 422;
+            break;
+        case VLC_CODEC_I444:
+        case VLC_CODEC_J444:
+            chromaformat = 444;
             break;
         default:
-            msg_Warn( p_filter, "Unsupported input chroma (%4.4s)",
+            msg_Err( p_filter, "Unsupported input chroma (%4.4s)",
                       (char*)&(p_inpic->format.i_chroma) );
             picture_Release( p_inpic );
             return NULL;
     }
 
-    /* CORRECT METHOD BUT COMMENTED OUT WHILE 'DROPPING PICTURES' ISSUE REMAINS
+    /* CORRECT METHOD BUT COMMENTED OUT WHILE 'DROPPING PICTURES' ISSUE REMAINS */
+
+	/* calculate time difference and find mid point (to insert other frame at) *//*
+	mtime_t i_currentTime = p_inpic->date;
+	mtime_t i_midPoint = p_sys->i_lastTime + (i_currentTime - p_sys->i_lastTime) / 2;
+	p_sys->i_lastTime = i_currentTime;
 
     picture_t *p_leftOut;
     picture_t *p_rightOut;
-    p_leftOut = DecodeImageYUV( p_filter, p_inpic, p_sys->i_leftEyeMethod, yuv422);
+    p_leftOut = DecodeImageYUV( p_filter, p_inpic, p_sys->i_leftEyeMethod, chromaformat);
     if( !p_leftOut )
     {
         msg_Warn( p_filter, "can't get left output picture" );
@@ -465,7 +921,7 @@ static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
     p_leftOut->i_eye = 1;
 
     p_leftOut->p_next = p_rightOut = DecodeImageYUV( p_filter, p_inpic,
-        p_sys->i_rightEyeMethod, yuv422);
+        p_sys->i_rightEyeMethod, chromaformat);
 
     if( !p_rightOut )
     {
@@ -475,6 +931,7 @@ static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
         return NULL;
     }
 
+	p_rightOut->date = i_midPoint;
     p_rightOut->i_eye = 2;
 
     picture_Release(p_inpic);
@@ -483,14 +940,14 @@ static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
 
     /* DECODES LEFT AND RIGHT FRAMES ALTERNATIVELY, DROPS A FRAME BUT IS A
        WORKAROUND UNTIL DROPPING PICTURES IS FIXED */
-
+	
     if(p_sys->b_leftEyeLast)
     {
         p_sys->b_leftEyeLast = false;
 
         /* do right eye */
         picture_t *p_rightOut = DecodeImageYUV( p_filter, p_inpic,
-            p_sys->i_rightEyeMethod, yuv422);
+            p_sys->i_rightEyeMethod, chromaformat);
 
         if( !p_rightOut )
         {
@@ -509,7 +966,7 @@ static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
 
         /* do left eye */
         picture_t *p_leftOut = DecodeImageYUV( p_filter, p_inpic,
-            p_sys->i_leftEyeMethod, yuv422);
+            p_sys->i_leftEyeMethod, chromaformat);
 
         if( !p_leftOut )
         {
@@ -527,9 +984,21 @@ static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
 /*****************************************************************************
  * Colour conversion methods. These methods are based on those in extract.c.
  *****************************************************************************/
-static void get_red_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_red_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_red_from_yuv411 not implemented");
+}
+
+static void get_red_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -594,9 +1063,10 @@ static void get_red_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_red_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_red_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -646,9 +1116,33 @@ static void get_red_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_cyan_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_red_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_red_from_yuv444 not implemented");
+}
+
+
+static void get_cyan_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_cyan_from_yuv411 not implemented");
+}
+
+static void get_cyan_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -713,9 +1207,10 @@ static void get_cyan_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_cyan_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_cyan_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -765,9 +1260,33 @@ static void get_cyan_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_green_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+
+static void get_cyan_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_cyan_from_yuv444 not implemented");
+}
+
+static void get_green_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_green_from_yuv411 not implemented");
+}
+
+static void get_green_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -832,9 +1351,10 @@ static void get_green_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_green_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_green_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                    int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -884,9 +1404,32 @@ static void get_green_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_magenta_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_green_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_green_from_yuv444 not implemented");
+}
+
+static void get_magenta_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_magenta_from_yuv411 not implemented");
+}
+
+static void get_magenta_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -951,9 +1494,10 @@ static void get_magenta_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_magenta_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_magenta_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1003,9 +1547,32 @@ static void get_magenta_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_blue_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_magenta_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_magenta_from_yuv444 not implemented");
+}
+
+static void get_blue_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_blue_from_yuv411 not implemented");
+}
+
+static void get_blue_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1070,9 +1637,10 @@ static void get_blue_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_blue_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_blue_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1122,9 +1690,32 @@ static void get_blue_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_yellow_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_blue_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_blue_from_yuv444 not implemented");
+}
+
+static void get_yellow_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_yellow_from_yuv411 not implemented");
+}
+
+static void get_yellow_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1189,9 +1780,10 @@ static void get_yellow_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_yellow_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_yellow_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1241,10 +1833,33 @@ static void get_yellow_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
+static void get_yellow_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_yellow_from_yuv444 not implemented");
+}
+
 /****** grayscale variations ******/
-static void get_red_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_red_grayscale_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_red_grayscale_from_yuv411 not implemented");
+}
+
+static void get_red_grayscale_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1309,9 +1924,10 @@ static void get_red_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_outp
     }
 }
 
-static void get_red_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_red_grayscale_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1361,9 +1977,32 @@ static void get_red_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_outp
     }
 }
 
-static void get_cyan_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_red_grayscale_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_red_grayscale_from_yuv444 not implemented");
+}
+
+static void get_cyan_grayscale_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_cyan_grayscale_from_yuv411 not implemented");
+}
+
+static void get_cyan_grayscale_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1433,9 +2072,10 @@ static void get_cyan_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_out
     }
 }
 
-static void get_cyan_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_cyan_grayscale_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1488,9 +2128,32 @@ static void get_cyan_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_out
     }
 }
 
-static void get_green_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_cyan_grayscale_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_cyan_grayscale_from_yuv444 not implemented");
+}
+
+static void get_green_grayscale_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_green_grayscale_from_yuv411 not implemented");
+}
+
+static void get_green_grayscale_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1555,9 +2218,10 @@ static void get_green_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_ou
     }
 }
 
-static void get_green_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_green_grayscale_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                    int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1607,9 +2271,32 @@ static void get_green_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_ou
     }
 }
 
-static void get_magenta_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_green_grayscale_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_green_grayscale_from_yuv444 not implemented");
+}
+
+static void get_magenta_grayscale_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_magenta_grayscale_from_yuv411 not implemented");
+}
+
+static void get_magenta_grayscale_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1679,9 +2366,10 @@ static void get_magenta_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_
     }
 }
 
-static void get_magenta_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_magenta_grayscale_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1734,9 +2422,32 @@ static void get_magenta_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_
     }
 }
 
-static void get_blue_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_magenta_grayscale_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_magenta_grayscale_from_yuv444 not implemented");
+}
+
+static void get_blue_grayscale_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_blue_grayscale_from_yuv411 not implemented");
+}
+
+static void get_blue_grayscale_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1801,9 +2512,10 @@ static void get_blue_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_out
     }
 }
 
-static void get_blue_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_blue_grayscale_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1853,9 +2565,32 @@ static void get_blue_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_out
     }
 }
 
-static void get_yellow_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_blue_grayscale_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_blue_grayscale_from_yuv444 not implemented");
+}
+
+static void get_yellow_grayscale_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_yellow_grayscale_from_yuv411 not implemented");
+}
+
+static void get_yellow_grayscale_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -1925,9 +2660,10 @@ static void get_yellow_grayscale_from_yuv420( picture_t *p_inpic, picture_t *p_o
     }
 }
 
-static void get_yellow_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_yellow_grayscale_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -1980,10 +2716,33 @@ static void get_yellow_grayscale_from_yuv422( picture_t *p_inpic, picture_t *p_o
     }
 }
 
+static void get_yellow_grayscale_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_yellow_grayscale_from_yuv444 not implemented");
+}
+
 /****** fill in missing channel variations ******/
-static void get_cyan_fill_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_cyan_fill_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_cyan_fill_from_yuv411 not implemented");
+}
+
+static void get_cyan_fill_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -2053,9 +2812,10 @@ static void get_cyan_fill_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_cyan_fill_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_cyan_fill_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -2108,9 +2868,32 @@ static void get_cyan_fill_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     }
 }
 
-static void get_magenta_fill_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_cyan_fill_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_cyan_fill_from_yuv444 not implemented");
+}
+
+static void get_magenta_fill_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_magenta_fill_from_yuv411 not implemented");
+}
+
+static void get_magenta_fill_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -2180,9 +2963,10 @@ static void get_magenta_fill_from_yuv420( picture_t *p_inpic, picture_t *p_outpi
     }
 }
 
-static void get_magenta_fill_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_magenta_fill_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -2235,9 +3019,32 @@ static void get_magenta_fill_from_yuv422( picture_t *p_inpic, picture_t *p_outpi
     }
 }
 
-static void get_yellow_fill_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_magenta_fill_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_magenta_fill_from_yuv444 not implemented");
+}
+
+static void get_yellow_fill_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_yellow_fill_from_yuv411 not implemented");
+}
+
+static void get_yellow_fill_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -2307,9 +3114,10 @@ static void get_yellow_fill_from_yuv420( picture_t *p_inpic, picture_t *p_outpic
     }
 }
 
-static void get_yellow_fill_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_yellow_fill_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
                                  int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -2362,9 +3170,34 @@ static void get_yellow_fill_from_yuv422( picture_t *p_inpic, picture_t *p_outpic
     }
 }
 
-static void get_lefthalf_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_yellow_fill_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+                                 int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_yellow_fill_from_yuv444 not implemented");
+}
+
+/****** side by side ******/
+
+static void get_lefthalf_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+    int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_lefthalf_from_yuv411 not implemented");
+}
+
+static void get_lefthalf_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
     int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -2383,7 +3216,6 @@ static void get_lefthalf_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
     const int i_uv_visible_pitch = p_inpic->p[up].i_visible_pitch;
 
     const uint8_t *yend = y1in + i_visible_lines * i_in_pitch;
-    int avg;
     while( y1in < yend )
     {
         /* only go up to half way */
@@ -2429,18 +3261,19 @@ static void get_lefthalf_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
             y2in++;
 
         }
-        y1in  += (i_in_pitch / 2) + 2*i_in_pitch  - i_visible_pitch;
-        y1out += 2*i_out_pitch - i_visible_pitch;
-        uin   += (p_inpic->p[up].i_pitch / 2) + p_inpic->p[up].i_pitch - i_uv_visible_pitch;
+        y1in  += (i_visible_pitch / 2) + i_in_pitch - i_visible_pitch;
+        y1out += i_out_pitch - i_visible_pitch;
+        uin   += (i_uv_visible_pitch / 2) + p_inpic->p[up].i_pitch - i_uv_visible_pitch;
         uout  += p_outpic->p[up].i_pitch - i_uv_visible_pitch;
-        vin   += (p_inpic->p[vp].i_pitch / 2) + p_inpic->p[vp].i_pitch - i_uv_visible_pitch;
+        vin   += (i_uv_visible_pitch / 2) + p_inpic->p[vp].i_pitch - i_uv_visible_pitch;
         vout  += p_outpic->p[vp].i_pitch - i_uv_visible_pitch;
     }
 }
 
-static void get_lefthalf_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_lefthalf_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
     int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -2457,7 +3290,6 @@ static void get_lefthalf_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
     const int i_uv_visible_pitch = p_inpic->p[up].i_visible_pitch;
 
     const uint8_t *yend = y1in + i_visible_lines * i_in_pitch;
-    int avg;
     while( y1in < yend )
     {
         /* only go up to half way */
@@ -2488,18 +3320,41 @@ static void get_lefthalf_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
             y1out++;
             y1in++;
         }
-        y1in  += (i_in_pitch / 2) + i_in_pitch  - i_visible_pitch;
+        y1in  += (i_visible_pitch / 2) + i_in_pitch - i_visible_pitch;
         y1out += i_out_pitch - i_visible_pitch;
-        uin   += (p_inpic->p[up].i_pitch / 2) + p_inpic->p[up].i_pitch - i_uv_visible_pitch;
+        uin   += (i_uv_visible_pitch / 2) + p_inpic->p[up].i_pitch - i_uv_visible_pitch;
         uout  += p_outpic->p[up].i_pitch - i_uv_visible_pitch;
-        vin   += (p_inpic->p[vp].i_pitch / 2) + p_inpic->p[vp].i_pitch - i_uv_visible_pitch;
+        vin   += (i_uv_visible_pitch / 2) + p_inpic->p[vp].i_pitch - i_uv_visible_pitch;
         vout  += p_outpic->p[vp].i_pitch - i_uv_visible_pitch;
     }
 }
 
-static void get_righthalf_from_yuv420( picture_t *p_inpic,
+static void get_lefthalf_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+    int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_lefthalf_from_yuv444 not implemented");
+}
+
+static void get_righthalf_from_yuv411( filter_t *p_filter, picture_t *p_inpic,
     picture_t *p_outpic, int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_righthalf_from_yuv411 not implemented");
+}
+
+static void get_righthalf_from_yuv420( filter_t *p_filter, picture_t *p_inpic,
+    picture_t *p_outpic, int yp, int up, int vp )
+{
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *y2in;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
@@ -2518,7 +3373,6 @@ static void get_righthalf_from_yuv420( picture_t *p_inpic,
     const int i_uv_visible_pitch = p_inpic->p[up].i_visible_pitch;
 
     const uint8_t *yend = y1in + i_visible_lines * i_in_pitch;
-    int avg;
     while( y1in < yend )
     {
         const uint8_t *y1end = y1in + i_visible_pitch;
@@ -2527,8 +3381,8 @@ static void get_righthalf_from_yuv420( picture_t *p_inpic,
         y2in  = y1in + i_in_pitch;
         y2out = y1out + i_out_pitch;
 
-        uin   += p_inpic->p[up].i_pitch / 2;
-        vin   += p_inpic->p[vp].i_pitch  / 2;
+        uin   += i_uv_visible_pitch / 2;
+        vin   += i_uv_visible_pitch  / 2;
         while( y1in < y1end )
         {
             *uout = *uin;
@@ -2568,8 +3422,8 @@ static void get_righthalf_from_yuv420( picture_t *p_inpic,
             y2in++;
 
         }
-        y1in  += 2*i_in_pitch  - i_visible_pitch;
-        y1out += 2*i_out_pitch - i_visible_pitch;
+        y1in  += i_in_pitch  - i_visible_pitch;
+        y1out += i_out_pitch - i_visible_pitch;
         uin   += p_inpic->p[up].i_pitch - i_uv_visible_pitch;
         uout  += p_outpic->p[up].i_pitch - i_uv_visible_pitch;
         vin   += p_inpic->p[vp].i_pitch  - i_uv_visible_pitch;
@@ -2577,9 +3431,10 @@ static void get_righthalf_from_yuv420( picture_t *p_inpic,
     }
 }
 
-static void get_righthalf_from_yuv422( picture_t *p_inpic,
+static void get_righthalf_from_yuv422( filter_t *p_filter, picture_t *p_inpic,
     picture_t *p_outpic, int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
     uint8_t *y1in = p_inpic->p[yp].p_pixels;
     uint8_t *uin  = p_inpic->p[up].p_pixels;
     uint8_t *vin  = p_inpic->p[vp].p_pixels;
@@ -2596,15 +3451,14 @@ static void get_righthalf_from_yuv422( picture_t *p_inpic,
     const int i_uv_visible_pitch = p_inpic->p[up].i_visible_pitch;
 
     const uint8_t *yend = y1in + i_visible_lines * i_in_pitch;
-    int avg;
     while( y1in < yend )
     {
         const uint8_t *y1end = y1in + i_visible_pitch;
         /* start at half way */
         y1in += i_visible_pitch / 2;
 
-        uin   += p_inpic->p[up].i_pitch / 2;
-        vin   += p_inpic->p[vp].i_pitch  / 2;
+        uin   += i_uv_visible_pitch / 2;
+        vin   += i_uv_visible_pitch  / 2;
         while( y1in < y1end )
         {
             *uout = *uin;
@@ -2640,23 +3494,212 @@ static void get_righthalf_from_yuv422( picture_t *p_inpic,
     }
 }
 
-static void get_tophalf_from_yuv420( picture_t *p_inpic, picture_t *p_outpic,
+static void get_righthalf_from_yuv444( filter_t *p_filter, picture_t *p_inpic,
+    picture_t *p_outpic, int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_righthalf_from_yuv444 not implemented");
+}
+
+static void get_tophalf_from_yuv411( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
     int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_tophalf_from_yuv411 not implemented");
 }
 
-static void get_tophalf_from_yuv422( picture_t *p_inpic, picture_t *p_outpic,
+static void get_tophalf_from_yuv420( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
     int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
+    uint8_t *y1in = p_inpic->p[yp].p_pixels;
+    uint8_t *y2in;
+    uint8_t *uin  = p_inpic->p[up].p_pixels;
+    uint8_t *vin  = p_inpic->p[vp].p_pixels;
+
+    uint8_t *y1out = p_outpic->p[yp].p_pixels;
+    uint8_t *y2out;
+    uint8_t *uout  = p_outpic->p[up].p_pixels;
+    uint8_t *vout  = p_outpic->p[vp].p_pixels;
+
+    const int i_in_pitch  = p_inpic->p[yp].i_pitch;
+    const int i_out_pitch = p_outpic->p[yp].i_pitch;
+
+    const int i_visible_pitch = p_inpic->p[yp].i_visible_pitch;
+    const int i_visible_lines = p_inpic->p[yp].i_visible_lines;
+    const int i_uv_visible_pitch = p_inpic->p[up].i_visible_pitch;
+
+    const uint8_t *yend = y1in + i_visible_lines * i_in_pitch;
+    
+    while( y1in < yend )
+    {
+        const uint8_t *y1end = y1in + i_visible_pitch;
+        y2in  = y1in + i_in_pitch;
+        y2out = y1out + i_out_pitch;
+        while( y1in < y1end )
+        {
+			*(y1out + i_out_pitch) = *y1out = *y1in;
+			*(y2out + i_out_pitch) = *y2out = *y2in;
+            
+            y1in++;
+            y2in++;
+
+            y1out++;
+            y2out++;
+
+            *(y1out + i_out_pitch) = *y1out = *y1in;
+			*(y2out + i_out_pitch) = *y2out = *y2in;
+			
+            y1in++;
+            y2in++;
+
+            y1out++;
+            y2out++;
+
+			*(uout + p_outpic->p[up].i_pitch) = *uout = *uin;
+			*(vout + p_outpic->p[vp].i_pitch) = *vout = *vin;
+
+
+            uin++;
+            vin++;
+            uout++;
+            vout++;
+        }
+        y1in  += 2*i_in_pitch  - i_visible_pitch;
+        y1out += 4*i_out_pitch - i_visible_pitch;
+        uin   += p_inpic->p[up].i_pitch - i_uv_visible_pitch;
+        uout  += 2*p_outpic->p[up].i_pitch - i_uv_visible_pitch;
+        vin   += p_inpic->p[vp].i_pitch  - i_uv_visible_pitch;
+        vout  += 2*p_outpic->p[vp].i_pitch - i_uv_visible_pitch;
+    }
+}
+
+static void get_tophalf_from_yuv422( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+    int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_tophalf_from_yuv422 not implemented");
+}
+
+static void get_tophalf_from_yuv444( filter_t *p_filter, picture_t *p_inpic, picture_t *p_outpic,
+    int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_tophalf_from_yuv444 not implemented");
 }
 
-static void get_bottomhalf_from_yuv420( picture_t *p_inpic,
+static void get_bottomhalf_from_yuv411( filter_t *p_filter, picture_t *p_inpic,
     picture_t *p_outpic, int yp, int up, int vp )
 {
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_bottomhalf_from_yuv411 not implemented");
 }
 
-static void get_bottomhalf_from_yuv422( picture_t *p_inpic,
+static void get_bottomhalf_from_yuv420( filter_t *p_filter, picture_t *p_inpic,
     picture_t *p_outpic, int yp, int up, int vp )
 {
+    VLC_UNUSED(p_filter);
+	/* start ins halfway down */
+    uint8_t *y1in = p_inpic->p[yp].p_pixels + p_inpic->p[yp].i_pitch * (p_inpic->p[yp].i_visible_lines / 2);
+    uint8_t *y2in;
+    uint8_t *uin  = p_inpic->p[up].p_pixels + p_inpic->p[up].i_pitch * (p_inpic->p[up].i_visible_lines / 2);
+    uint8_t *vin  = p_inpic->p[vp].p_pixels + p_inpic->p[vp].i_pitch * (p_inpic->p[vp].i_visible_lines / 2);
+
+    uint8_t *y1out = p_outpic->p[yp].p_pixels;
+    uint8_t *y2out;
+    uint8_t *uout  = p_outpic->p[up].p_pixels;
+    uint8_t *vout  = p_outpic->p[vp].p_pixels;
+
+    const int i_in_pitch  = p_inpic->p[yp].i_pitch;
+    const int i_out_pitch = p_outpic->p[yp].i_pitch;
+
+    const int i_visible_pitch = p_inpic->p[yp].i_visible_pitch;
+    const int i_visible_lines = p_inpic->p[yp].i_visible_lines;
+    const int i_uv_visible_pitch = p_inpic->p[up].i_visible_pitch;
+
+    const uint8_t *yend = y1in + i_visible_lines * i_in_pitch;
+    
+    while( y1in < yend )
+    {
+        const uint8_t *y1end = y1in + i_visible_pitch;
+        y2in  = y1in + i_in_pitch;
+        y2out = y1out + i_out_pitch;
+        while( y1in < y1end )
+        {
+			*(y1out + i_out_pitch) = *y1out = *y1in;
+			*(y2out + i_out_pitch) = *y2out = *y2in;
+            
+            y1in++;
+            y2in++;
+
+            y1out++;
+            y2out++;
+
+            *(y1out + i_out_pitch) = *y1out = *y1in;
+			*(y2out + i_out_pitch) = *y2out = *y2in;
+			
+            y1in++;
+            y2in++;
+
+            y1out++;
+            y2out++;
+
+			*(uout + p_outpic->p[up].i_pitch) = *uout = *uin;
+			*(vout + p_outpic->p[vp].i_pitch) = *vout = *vin;
+
+
+            uin++;
+            vin++;
+            uout++;
+            vout++;
+        }
+        y1in  += 2*i_in_pitch  - i_visible_pitch;
+        y1out += 4*i_out_pitch - i_visible_pitch;
+        uin   += p_inpic->p[up].i_pitch - i_uv_visible_pitch;
+        uout  += 2*p_outpic->p[up].i_pitch - i_uv_visible_pitch;
+        vin   += p_inpic->p[vp].i_pitch  - i_uv_visible_pitch;
+        vout  += 2*p_outpic->p[vp].i_pitch - i_uv_visible_pitch;
+    }
 }
 
+static void get_bottomhalf_from_yuv422( filter_t *p_filter, picture_t *p_inpic,
+    picture_t *p_outpic, int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_bottomhalf_from_yuv422 not implemented");
+}
+
+static void get_bottomhalf_from_yuv444( filter_t *p_filter, picture_t *p_inpic,
+    picture_t *p_outpic, int yp, int up, int vp )
+{
+    VLC_UNUSED(p_inpic);
+    VLC_UNUSED(p_outpic);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: get_bottomhalf_from_yuv444 not implemented");
+}
diff --git a/modules/video_filter/stereoscopycombine.c b/modules/video_filter/stereoscopycombine.c
new file mode 100644
index 0000000..c2dd55e
--- /dev/null
+++ b/modules/video_filter/stereoscopycombine.c
@@ -0,0 +1,816 @@
+/*****************************************************************************
+ * stereoscopycombine.c : stereoscopy combine video filter - takes two
+ * images (one for each eye) and combines them into a single image
+ *****************************************************************************
+ * Copyright (C) 2011 the VideoLAN team
+ *
+ * Authors: Andrew Price <andrewprice@andrewalexanderprice.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+/*****************************************************************************
+ * Preamble
+ *****************************************************************************/
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <vlc_common.h>
+#include <vlc_plugin.h>
+#include <vlc_rand.h>
+
+#include <vlc_filter.h>
+#include "filter_picture.h"
+
+#include <vlc_fixups.h>
+
+/*****************************************************************************
+ * Local prototypes
+ *****************************************************************************/
+static int  Create    ( vlc_object_t * );
+static picture_t *Filter( filter_t *, picture_t * );
+static void Destroy( vlc_object_t *p_this );
+
+static int OutputModeStrToValue(const char *str);
+
+static picture_t *CombinePictures( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int chromaformat );
+
+
+/* combiner methods, each take two pictures and return one */
+static picture_t *combine_red_cyan_yuv411( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_cyan_yuv420( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_cyan_yuv422( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_cyan_yuv444( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_green_yuv411( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_green_yuv420( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_green_yuv422( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_green_yuv444( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_blue_yuv411( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_blue_yuv420( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_blue_yuv422( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_red_blue_yuv444( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_magenta_yuv411( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_magenta_yuv420( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_magenta_yuv422( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_magenta_yuv444( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_blue_yuv411( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_blue_yuv420( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_blue_yuv422( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_green_blue_yuv444( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_blue_yellow_yuv411( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_blue_yellow_yuv420( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_blue_yellow_yuv422( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+static picture_t *combine_blue_yellow_yuv444( filter_t *p_filter, picture_t *, picture_t *t, int, int, int );
+
+
+/* output modes */
+#define STEREOSCOPY_COMBINE_MODE_RED_CYAN                    0
+#define STEREOSCOPY_COMBINE_MODE_CYAN_RED                    1
+#define STEREOSCOPY_COMBINE_MODE_RED_GREEN                   2
+#define STEREOSCOPY_COMBINE_MODE_GREEN_RED                   3
+#define STEREOSCOPY_COMBINE_MODE_RED_BLUE                    4
+#define STEREOSCOPY_COMBINE_MODE_BLUE_RED                    5
+#define STEREOSCOPY_COMBINE_MODE_GREEN_MAGENTA               6
+#define STEREOSCOPY_COMBINE_MODE_MAGENTA_GREEN               7
+#define STEREOSCOPY_COMBINE_MODE_GREEN_BLUE                  8
+#define STEREOSCOPY_COMBINE_MODE_BLUE_GREEN                  9
+#define STEREOSCOPY_COMBINE_MODE_BLUE_YELLOW                 10
+#define STEREOSCOPY_COMBINE_MODE_YELLOW_BLUE                 11
+
+#define FILTER_PREFIX "stereoscopy-combine-"
+
+
+#define OUTPUT_METHOD_TEXT N_("Output stereoscopy encoding")
+#define OUTPUT_METHOD_LONGTEXT N_("Represents the form of steroscopic "\
+                                    "encoding used for the image of the "\
+                                    "respective eye. " \
+									"rc - Red/Cyan (Anaglyph). " \
+									"cr - Cyan/Red (Anaglyph). " \
+									"rg - Red/Green (Anaglyph). " \
+									"gr - Green/Red (Anaglyph). " \
+									"rb - Red/Blue (Anaglyph). " \
+									"br - Blue/Red (Anaglyph). " \
+									"gm - Green/Magenta (Anaglyph). " \
+									"mg - Magenta/Green (Anaglyph). " \
+									"gb - Green/Blue (Anaglyph). " \
+									"bg - Blue/Green (Anaglyph). " \
+									"yb - Yellow/Blue (Anaglyph). " \
+									"by - Blue/Yellow (Anaglyph). ")
+
+
+static const char * const type_list_text[] = { N_("Red/Cyan (Anaglyph)"),
+	N_("Cyan/Red (Anaglyph)"), N_("Red/Green (Anaglyph)"), N_("Green/Red (Anaglyph)"),
+    N_("Red/Blue (Anaglyph)"), N_("Blue/Red (Anaglyph)"), N_("Green/Magenta (Anaglyph)"),
+    N_("Magenta/Green (Anaglyph)"), N_("Green/Blue (Anaglyph)"),
+    N_("Blue/Green (Anaglyph)"), N_("Blue/Yellow (Anaglyph)"),
+    N_("Yellow/Blue (Anaglyph)") };
+
+static const char * const type_list[] = { "rc", "cr", "rg",
+	"gr", "rb", "br", "gm", "mg", "gb",
+	"bg", "by", "yb"};
+
+struct filter_sys_t
+{
+	picture_t *p_lastLeftEye;
+	picture_t *p_lastRightEye;
+    int    i_outputMethod;
+};
+
+
+/*****************************************************************************
+ * Module descriptor
+ *****************************************************************************/
+vlc_module_begin ()
+    set_description( N_("Stereoscopy combine video filter") )
+    set_shortname( N_( "Stereoscopy Combine" ))
+    set_capability( "video filter2", 0 )
+    set_category( CAT_VIDEO )
+    set_subcategory( SUBCAT_VIDEO_VFILTER )
+	
+    add_string("stereoscopic-output", "rg", OUTPUT_METHOD_TEXT, OUTPUT_METHOD_LONGTEXT, false)
+        change_string_list(type_list, type_list_text, 0)
+
+    add_shortcut( "stereoscopy-combine" )
+    set_callbacks( Create, Destroy )
+
+vlc_module_end ()
+
+/*****************************************************************************
+ * Create: initialises stereoscopy combine video filter
+ *****************************************************************************
+ * This function allocates and initializes a stereoscopy combine filter.
+ *****************************************************************************/
+static int Create( vlc_object_t *p_this )
+{
+    filter_t *p_filter;
+    filter_sys_t *p_sys;
+    char *outputMethod;
+
+    p_filter = (filter_t *)p_this;
+    p_filter->pf_video_filter = Filter;
+    p_sys = p_filter->p_sys = malloc(sizeof(*p_sys));
+
+    if( !p_sys )
+        return VLC_ENOMEM;
+
+	/* read in method for left eye */
+	outputMethod = var_InheritString( p_filter, "stereoscopic-output" );
+	p_sys->i_outputMethod = OutputModeStrToValue(outputMethod);
+	free(outputMethod);
+
+	p_sys->p_lastLeftEye = NULL;
+	p_sys->p_lastRightEye = NULL;
+
+	return VLC_SUCCESS;
+}
+
+
+/*****************************************************************************
+ * Destroy: destroy  stereoscopy combine video filter
+ *****************************************************************************
+ * Destroys sterescopy combine video filter
+ *****************************************************************************/
+static void Destroy( vlc_object_t *p_this )
+{
+    filter_t *p_filter = (filter_t*)p_this;
+
+	filter_sys_t *p_sys = p_filter->p_sys;
+	
+	/* ensure any saved pictures are released */
+	if( p_sys->p_lastLeftEye != NULL )
+        picture_Release( p_sys->p_lastLeftEye );
+	
+	if( p_sys->p_lastRightEye != NULL )
+        picture_Release( p_sys->p_lastRightEye );
+
+
+    free( p_filter->p_sys );
+}
+
+/*****************************************************************************
+ * InputModeStrToValue: input mode string to value method
+ *****************************************************************************
+ * Converts the string of an input mode (e.g. "left") to it's value
+ * (e.g. STEREOSCOPY_SIDEBYSIDE_LEFT).
+ *****************************************************************************/
+static int OutputModeStrToValue(const char *str) {
+    if(strcmp(str, "rc") == 0)
+        return STEREOSCOPY_COMBINE_MODE_RED_CYAN;
+    if(strcmp(str, "cr") == 0)
+        return STEREOSCOPY_COMBINE_MODE_CYAN_RED;
+    if(strcmp(str, "rg") == 0)
+        return STEREOSCOPY_COMBINE_MODE_RED_GREEN;
+    if(strcmp(str, "gr") == 0)
+        return STEREOSCOPY_COMBINE_MODE_GREEN_RED;
+    if(strcmp(str, "rb") == 0)
+        return STEREOSCOPY_COMBINE_MODE_RED_BLUE;
+    if(strcmp(str, "br") == 0)
+        return STEREOSCOPY_COMBINE_MODE_BLUE_RED;
+    if(strcmp(str, "gm") == 0)
+        return STEREOSCOPY_COMBINE_MODE_GREEN_MAGENTA;
+    if(strcmp(str, "mg") == 0)
+        return STEREOSCOPY_COMBINE_MODE_MAGENTA_GREEN;
+    if(strcmp(str, "gb") == 0)
+        return STEREOSCOPY_COMBINE_MODE_GREEN_BLUE;
+    if(strcmp(str, "bg") == 0)
+        return STEREOSCOPY_COMBINE_MODE_BLUE_GREEN;
+    if(strcmp(str, "by") == 0)
+        return STEREOSCOPY_COMBINE_MODE_BLUE_YELLOW;
+    if(strcmp(str, "yb") == 0)
+        return STEREOSCOPY_COMBINE_MODE_YELLOW_BLUE;
+
+    /* nothing left */
+    return STEREOSCOPY_COMBINE_MODE_RED_CYAN;
+}
+
+
+/*****************************************************************************
+ * Render: displays previously rendered output
+ *****************************************************************************
+ * This function takes a single frame and divides the image up into seperate
+ * eyes, returning two frames.
+ *****************************************************************************/
+static picture_t *Filter( filter_t *p_filter, picture_t *p_inpic )
+{
+    filter_sys_t *p_sys;
+    int chromaformat;
+
+    if( !p_inpic ) return NULL;
+
+    if( (p_filter->fmt_in.video.i_height == 0) ||
+        (p_filter->fmt_in.video.i_width == 0) )
+        return NULL;
+
+    if( (p_filter->fmt_out.video.i_height == 0) ||
+        (p_filter->fmt_out.video.i_width == 0) )
+        return NULL;
+
+    p_sys = p_filter->p_sys;
+
+    /* already a 2d image so do nothing */
+    if( p_inpic->i_eye == 0 )
+        return p_inpic;
+
+	/* if left eye */
+	if( p_inpic->i_eye == 1 )
+	{
+		if( p_sys->p_lastLeftEye != NULL )
+            picture_Release( p_sys->p_lastLeftEye );
+
+		p_sys->p_lastLeftEye = p_inpic;
+	}
+
+	/* if right eye */
+	if( p_inpic->i_eye == 2 )
+	{
+		if( p_sys->p_lastRightEye != NULL )
+            picture_Release( p_sys->p_lastRightEye );
+
+		p_sys->p_lastRightEye = p_inpic;
+	}
+
+	/* needs at least one of each eye to continue */
+	if( p_sys->p_lastLeftEye == NULL || p_sys->p_lastRightEye == NULL )
+	{
+		return NULL;
+	}
+
+    switch( p_inpic->format.i_chroma )
+    {
+        case VLC_CODEC_I411:
+            chromaformat = 411;
+            break;
+        case VLC_CODEC_I420:
+        case VLC_CODEC_J420:
+            chromaformat = 420;
+            break;
+        case VLC_CODEC_YV12:
+        case VLC_CODEC_I422:
+        case VLC_CODEC_J422:
+            chromaformat = 422;
+            break;
+        case VLC_CODEC_I444:
+        case VLC_CODEC_J444:
+            chromaformat = 444;
+            break;
+        default:
+            msg_Err( p_filter, "Unsupported input chroma (%4.4s)",
+                      (char*)&(p_inpic->format.i_chroma) );
+            picture_Release( p_inpic );
+            return NULL;
+    }
+	
+	/* combine images */
+    picture_t *p_output = CombinePictures( p_filter, p_sys->p_lastLeftEye,
+        p_sys->p_lastRightEye, chromaformat);
+
+    if( !p_output )
+    {
+        msg_Warn( p_filter, "can't get output picture" );
+            return NULL;
+    }
+
+    p_output->i_eye = 0;
+    return p_output;
+}
+
+
+/*****************************************************************************
+ * CombinePictures: combines two images into a stereo image
+ *****************************************************************************
+ * Combines two seperate images into a single stereoscopic image based on the
+ * desired output format.
+ *****************************************************************************/
+static picture_t *CombinePictures( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int chromaformat )
+{
+	filter_sys_t *p_sys = (filter_sys_t *)p_filter->p_sys;
+
+	switch(p_sys->i_outputMethod)
+	{
+		case STEREOSCOPY_COMBINE_MODE_RED_CYAN:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_red_cyan_yuv411(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_red_cyan_yuv420(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_red_cyan_yuv422(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_red_cyan_yuv444(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+		break;
+		case STEREOSCOPY_COMBINE_MODE_CYAN_RED:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_red_cyan_yuv411(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_red_cyan_yuv420(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_red_cyan_yuv422(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_red_cyan_yuv444(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_RED_GREEN:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_red_green_yuv411(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_red_green_yuv420(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_red_green_yuv422(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_red_green_yuv444(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_GREEN_RED:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_red_green_yuv411(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_red_green_yuv420(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_red_green_yuv422(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_red_green_yuv444(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_RED_BLUE:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_red_blue_yuv411(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_red_blue_yuv420(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_red_blue_yuv422(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_red_blue_yuv444(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_BLUE_RED:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_red_blue_yuv411(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_red_blue_yuv420(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_red_blue_yuv422(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_red_blue_yuv444(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_GREEN_MAGENTA:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_green_magenta_yuv411(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_green_magenta_yuv420(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_green_magenta_yuv422(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_green_magenta_yuv444(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_MAGENTA_GREEN:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_green_magenta_yuv411(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_green_magenta_yuv420(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_green_magenta_yuv422(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_green_magenta_yuv444(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_GREEN_BLUE:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_green_blue_yuv411(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_green_blue_yuv420(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_green_blue_yuv422(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_green_blue_yuv444(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_BLUE_GREEN:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_green_blue_yuv411(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_green_blue_yuv420(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_green_blue_yuv422(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_green_blue_yuv444(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_BLUE_YELLOW:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_blue_yellow_yuv411(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_blue_yellow_yuv420(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_blue_yellow_yuv422(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_blue_yellow_yuv444(p_filter, p_in1, p_in2,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	case STEREOSCOPY_COMBINE_MODE_YELLOW_BLUE:
+			switch(chromaformat)
+			{
+				case 411:
+					return combine_blue_yellow_yuv411(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 420:
+					return combine_blue_yellow_yuv420(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 422:
+					return combine_blue_yellow_yuv422(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+				case 444:
+					return combine_blue_yellow_yuv444(p_filter, p_in2, p_in1,
+                        Y_PLANE, U_PLANE, V_PLANE);
+			}
+			break;
+	};
+
+	return NULL;
+}
+
+/* combining methods */
+static picture_t *combine_red_cyan_yuv411( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_cyan_yuv411 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_cyan_yuv420( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_cyan_yuv420 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_cyan_yuv422( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_cyan_yuv422 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_cyan_yuv444( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_cyan_yuv444 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_green_yuv411( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_green_yuv411 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_green_yuv420( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_green_yuv420 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_green_yuv422( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_green_yuv422 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_green_yuv444( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_green_yuv444 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_blue_yuv411( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_blue_yuv411 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_blue_yuv420( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_blue_yuv420 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_blue_yuv422( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_blue_yuv422 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_red_blue_yuv444( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_red_blue_yuv444 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_magenta_yuv411( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_magenta_yuv411 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_magenta_yuv420( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_magenta_yuv420 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_magenta_yuv422( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_magenta_yuv422 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_magenta_yuv444( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_magenta_yuv444 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_blue_yuv411( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_blue_yuv411 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_blue_yuv420( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_blue_yuv420 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_blue_yuv422( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_blue_yuv422 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_green_blue_yuv444( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_green_blue_yuv444 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_blue_yellow_yuv411( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_blue_yellow_yuv411 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_blue_yellow_yuv420( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_blue_yellow_yuv420 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_blue_yellow_yuv422( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_blue_yellow_yuv422 not implemented");
+	return NULL;
+}
+
+static picture_t *combine_blue_yellow_yuv444( filter_t *p_filter, picture_t *p_in1, picture_t *p_in2, int yp, int up, int vp)
+{
+    VLC_UNUSED(p_in1);
+    VLC_UNUSED(p_in2);
+    VLC_UNUSED(yp);
+    VLC_UNUSED(up);
+    VLC_UNUSED(vp);
+    msg_Err( p_filter, "stereoscopy.c: combine_blue_yellow_yuv444 not implemented");
+	return NULL;
+}
diff --git a/modules/video_output/msw/nvapi.c b/modules/video_output/msw/nvapi.c
new file mode 100644
index 0000000..72e60a4
--- /dev/null
+++ b/modules/video_output/msw/nvapi.c
@@ -0,0 +1,236 @@
+/*****************************************************************************
+ * nvapi.c: nVidia stereoscopic API
+ *****************************************************************************
+ * Copyright (C) 2011 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Andrew Price <andrewprice@andrewalexanderprice.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#include <windows.h>
+#include "nvapi.h"
+
+HMODULE h_nvapi; /* reference to nvapi dll */
+void *(__cdecl *p_queryInterface)(unsigned __int32);
+void (__cdecl *p_callStart)(unsigned __int32, unsigned __int64 *);
+int (__cdecl *p_callReturn)(unsigned __int32, unsigned __int32,
+	unsigned __int32, unsigned __int32);
+int (__cdecl *p_NvAPI_StereoIsEnabled)(unsigned char *);
+int (__cdecl *p_NvAPI_StereoCreateHandleFromIUnknown)(void *, StereoHandle *);
+int (__cdecl *p_NvAPI_StereoDestroyHandle)(StereoHandle);
+int (__cdecl *p_NvAPI_StereoIsActivated)(StereoHandle, unsigned char *);
+int (__cdecl *p_NvAPI_StereoActivate)(StereoHandle);
+int (__cdecl *p_NvAPI_StereoDeactivate)(StereoHandle);
+
+/* Initialises NvAPI (must be called first). Returns NV_OK if successful,
+   otherwise can fail for several reasons (not using latest nVidia drivers,
+   don't have an nVidia graphics card, etc). */
+NvAPI_Status NvAPI_Initialize(void)
+{
+	int (*p_NvAPIInitialise)(void); // [sp+0h] [bp-4h]@6
+
+	/* try to load nvapi */
+	h_nvapi = LoadLibraryA("nvapi.dll");
+	if( !h_nvapi )
+		return NVAPI_LIBRARY_NOT_FOUND;
+
+	p_queryInterface = (void *(__cdecl *)(unsigned __int32))GetProcAddress(h_nvapi, "nvapi_QueryInterface");
+	if( !p_queryInterface )
+	{
+		FreeLibrary(h_nvapi);
+		return NVAPI_ERROR;
+	}
+
+	p_NvAPIInitialise = (int (*)(void))p_queryInterface(0x150E828u);
+
+	if ( !p_NvAPIInitialise )
+	{
+		FreeLibrary(h_nvapi);
+		return NVAPI_ERROR;
+	}
+
+	if( p_NvAPIInitialise() != NVAPI_OK )
+	{
+		FreeLibrary(h_nvapi);
+		return NVAPI_ERROR;
+	}
+	
+	p_callStart = (void (__cdecl *)(unsigned __int32, unsigned __int64 *))p_queryInterface(0x33C7358Cu);
+	p_callReturn = (__int32 (__cdecl *)(unsigned __int32, unsigned __int32,
+		unsigned __int32, unsigned __int32))p_queryInterface(0x593E8644u);
+
+	if ( !p_callStart && !p_callReturn)
+	{
+		p_callStart = 0;
+		p_callReturn = 0;
+	}
+
+	/* load function pointers */
+	p_NvAPI_StereoIsEnabled = (int (__cdecl *)(unsigned char *))p_queryInterface(0x348FF8E1u);
+	p_NvAPI_StereoCreateHandleFromIUnknown = (int (__cdecl *)(void *, StereoHandle *))p_queryInterface(0xAC7E37F4u);
+	p_NvAPI_StereoDestroyHandle = (int (__cdecl *)(StereoHandle))p_queryInterface(0x3A153134u);
+	p_NvAPI_StereoIsActivated = (int (__cdecl *)(StereoHandle, unsigned char *))p_queryInterface(0x1FB0BC30u);
+	p_NvAPI_StereoActivate = (int (__cdecl *)(StereoHandle))p_queryInterface(0xF6A1AD68u);
+	p_NvAPI_StereoDeactivate = (int (__cdecl *)(StereoHandle))p_queryInterface(0x2D68DE96u);
+
+	return NVAPI_OK;
+}
+
+/* Unloads NvAPI (must be called last). This unloads nvapi.dll so forgetting
+   to call this will result in a memory leak. */
+NvAPI_Status NvAPI_Unload(void)
+{
+	/*signed int i;*/
+	int (*p_NvAPI_Unload)(void);
+
+	p_NvAPI_Unload = (int (*)(void))p_queryInterface(0xD22BDD7Eu);
+	if ( !p_NvAPI_Unload )
+		return NVAPI_NO_IMPLEMENTATION;
+
+	if ( p_NvAPI_Unload() != NVAPI_OK )
+		return NVAPI_ERROR;
+
+	p_queryInterface = 0;
+	h_nvapi = 0;
+	p_callStart = 0;
+	p_callReturn = 0;
+	FreeLibrary(h_nvapi);
+	return NVAPI_OK;
+}
+
+/* Sets pIsStereoEnabled to true if stereo enabled system wide. It will return
+   false if 3D Vision is disabled in the nVidia control panel or 3D vision is
+   not supported by the hardware. */
+NvAPI_Status NvAPI_Stereo_IsEnabled(unsigned char *pIsStereoEnabled)
+{
+	if(!p_NvAPI_StereoIsEnabled)
+		return NVAPI_NO_IMPLEMENTATION;
+	
+	int callStartReturn = 0;
+	int callStartReturn2 = 0;
+	if ( p_callStart )
+		p_callStart(0x348FF8E1u, (unsigned __int64 *)&callStartReturn);
+
+	NvAPI_Status result = p_NvAPI_StereoIsEnabled(pIsStereoEnabled);
+
+	if ( p_callReturn )
+		p_callReturn(881850593, callStartReturn, callStartReturn2, result);
+	return result;
+}
+
+/* Creates a stereo handle from a Direct3D device. This may be a D3D 9, D3D 10,
+   or D3D11 device. */
+extern NvAPI_Status NvAPI_Stereo_CreateHandleFromIUnknown(void *pDevice,
+	StereoHandle *pStereoHandle)
+{
+	if( !p_NvAPI_StereoCreateHandleFromIUnknown )
+		return NVAPI_NO_IMPLEMENTATION;
+
+	int callStartReturn = 0;
+	int callStartReturn2 = 0;
+	    if ( p_callStart )
+	       p_callStart(0xAC7E37F4u, (unsigned __int64 *)&callStartReturn);
+
+	    NvAPI_Status result = p_NvAPI_StereoCreateHandleFromIUnknown(pDevice, pStereoHandle);
+
+	    if ( p_callReturn )
+	      p_callReturn(-1401014284, callStartReturn, callStartReturn2, result);
+	    return result;
+}
+
+/* Destroys a stereo handle. Call this before unloading the NvAPI. */
+NvAPI_Status NvAPI_Stereo_DestroyHandle(StereoHandle stereoHandle)
+{
+	if( !p_NvAPI_StereoDestroyHandle )
+		return NVAPI_NO_IMPLEMENTATION;
+
+	int callStartReturn = 0;
+	int callStartReturn2 = 0;
+
+	if (  p_callStart )
+	       p_callStart(0x3A153134u, (unsigned __int64 *)&callStartReturn);
+
+	    NvAPI_Status result = p_NvAPI_StereoDestroyHandle(stereoHandle);
+
+	    if ( p_callReturn )
+	      p_callReturn(974467380, callStartReturn, callStartReturn2, result);
+	    return result;
+}
+
+
+/* Sets isStereoActivated to true if stereo is activated at that particular
+   point in time. This can be toggled using the Activate/Deactive calls,
+   pressing the button on the front of the 3D Vision USB dongle, or using
+   the nVidia hotkey (Ctrl+T by default). */
+extern NvAPI_Status NvAPI_Stereo_IsActivated(StereoHandle stereoHandle,
+	unsigned char *isStereoActivated)
+{
+	if( !p_NvAPI_StereoIsActivated )
+		return NVAPI_NO_IMPLEMENTATION;
+
+	int callStartReturn = 0;
+	int callStartReturn2 = 0;
+	if (  p_callStart )
+	       p_callStart(0x1FB0BC30u, (unsigned __int64 *)&callStartReturn);
+	    NvAPI_Status result = p_NvAPI_StereoIsActivated(stereoHandle, isStereoActivated);
+	    if ( p_callReturn )
+	      p_callReturn(531676208, callStartReturn, callStartReturn2, result);
+	return result;
+}
+
+/* Turns 3d Vision on in the application (as long as it is activated on the
+   system and you have a valid handle). Note that the user can manually turn
+   it off via the USB dongle or hotkey so you must constantly check if stereo
+   is activated. */
+NvAPI_Status NvAPI_Stereo_Activate(StereoHandle stereoHandle)
+{
+	if( !p_NvAPI_StereoActivate )
+		return NVAPI_NO_IMPLEMENTATION;
+
+	int callStartReturn = 0;
+	int callStartReturn2 = 0;
+    if (  p_callStart )
+       p_callStart(0xF6A1AD68u, (unsigned __int64 *)&callStartReturn);
+
+    NvAPI_Status result = p_NvAPI_StereoActivate(stereoHandle);
+
+    if ( p_callReturn )
+      p_callReturn(-157176472, callStartReturn, callStartReturn2, result);
+    return result;
+}
+
+/* Turns 3d Vision off in the application. Note that the user can manually
+   turn it on via the USB dongle or hotkey, so you must constantly check if
+   stereo is activated, and turn it off if you're playing 2d content. */
+NvAPI_Status NvAPI_Stereo_Deactivate(StereoHandle stereoHandle)
+{
+  if( !p_NvAPI_StereoDeactivate )
+	  return NVAPI_NO_IMPLEMENTATION;
+
+  int callStartReturn = 0;
+  int callStartReturn2 = 0;
+
+    if (  p_callStart )
+       p_callStart(0x2D68DE96u, (unsigned __int64 *)&callStartReturn);
+
+    NvAPI_Status result = p_NvAPI_StereoDeactivate(stereoHandle);
+
+    if ( p_callReturn )
+      p_callReturn(761847446, callStartReturn, callStartReturn2, result);
+
+    return result;
+}
\ No newline at end of file
diff --git a/modules/video_output/msw/nvapi.h b/modules/video_output/msw/nvapi.h
new file mode 100644
index 0000000..668bf48
--- /dev/null
+++ b/modules/video_output/msw/nvapi.h
@@ -0,0 +1,167 @@
+/*****************************************************************************
+ * nvapi.h: nVidia stereoscopic API
+ *****************************************************************************
+ * Copyright (C) 2011 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Andrew Price <andrewprice@andrewalexanderprice.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+typedef void* StereoHandle;
+
+typedef enum _NvAPI_Status
+{
+    NVAPI_OK                                    =  0,      // Success
+    NVAPI_ERROR                                 = -1,      // Generic error
+    NVAPI_LIBRARY_NOT_FOUND                     = -2,      // nvapi.dll can not be loaded
+    NVAPI_NO_IMPLEMENTATION                     = -3,      // not implemented in current driver installation
+    NVAPI_API_NOT_INITIALIZED                   = -4,      // NvAPI_Initialize has not been called (successfully)
+    NVAPI_INVALID_ARGUMENT                      = -5,      // invalid argument
+    NVAPI_NVIDIA_DEVICE_NOT_FOUND               = -6,      // no NVIDIA display driver was found
+    NVAPI_END_ENUMERATION                       = -7,      // no more to enum
+    NVAPI_INVALID_HANDLE                        = -8,      // invalid handle
+    NVAPI_INCOMPATIBLE_STRUCT_VERSION           = -9,      // an argument's structure version is not supported
+    NVAPI_HANDLE_INVALIDATED                    = -10,     // handle is no longer valid (likely due to GPU or display re-configuration)
+    NVAPI_OPENGL_CONTEXT_NOT_CURRENT            = -11,     // no NVIDIA OpenGL context is current (but needs to be)
+    NVAPI_INVALID_POINTER                       = -14,     // An invalid pointer, usually NULL, was passed as a parameter
+    NVAPI_NO_GL_EXPERT                          = -12,     // OpenGL Expert is not supported by the current drivers
+    NVAPI_INSTRUMENTATION_DISABLED              = -13,     // OpenGL Expert is supported, but driver instrumentation is currently disabled
+    NVAPI_NO_GL_NSIGHT                          = -15,     // OpenGL does not support Nsight
+    NVAPI_EXPECTED_LOGICAL_GPU_HANDLE           = -100,    // expected a logical GPU handle for one or more parameters
+    NVAPI_EXPECTED_PHYSICAL_GPU_HANDLE          = -101,    // expected a physical GPU handle for one or more parameters
+    NVAPI_EXPECTED_DISPLAY_HANDLE               = -102,    // expected an NV display handle for one or more parameters
+    NVAPI_INVALID_COMBINATION                   = -103,    // used in some commands to indicate that the combination of parameters is not valid
+    NVAPI_NOT_SUPPORTED                         = -104,    // Requested feature not supported in the selected GPU
+    NVAPI_PORTID_NOT_FOUND                      = -105,    // NO port ID found for I2C transaction
+    NVAPI_EXPECTED_UNATTACHED_DISPLAY_HANDLE    = -106,    // expected an unattached display handle as one of the input param
+    NVAPI_INVALID_PERF_LEVEL                    = -107,    // invalid perf level
+    NVAPI_DEVICE_BUSY                           = -108,    // device is busy, request not fulfilled
+    NVAPI_NV_PERSIST_FILE_NOT_FOUND             = -109,    // NV persist file is not found
+    NVAPI_PERSIST_DATA_NOT_FOUND                = -110,    // NV persist data is not found
+    NVAPI_EXPECTED_TV_DISPLAY                   = -111,    // expected TV output display
+    NVAPI_EXPECTED_TV_DISPLAY_ON_DCONNECTOR     = -112,    // expected TV output on D Connector - HDTV_EIAJ4120.
+    NVAPI_NO_ACTIVE_SLI_TOPOLOGY                = -113,    // SLI is not active on this device
+    NVAPI_SLI_RENDERING_MODE_NOTALLOWED         = -114,    // setup of SLI rendering mode is not possible right now
+    NVAPI_EXPECTED_DIGITAL_FLAT_PANEL           = -115,    // expected digital flat panel
+    NVAPI_ARGUMENT_EXCEED_MAX_SIZE              = -116,    // argument exceeds expected size
+    NVAPI_DEVICE_SWITCHING_NOT_ALLOWED          = -117,    // inhibit ON due to one of the flags in NV_GPU_DISPLAY_CHANGE_INHIBIT or SLI Active
+    NVAPI_TESTING_CLOCKS_NOT_SUPPORTED          = -118,    // testing clocks not supported
+    NVAPI_UNKNOWN_UNDERSCAN_CONFIG              = -119,    // the specified underscan config is from an unknown source (e.g. INF)
+    NVAPI_TIMEOUT_RECONFIGURING_GPU_TOPO        = -120,    // timeout while reconfiguring GPUs
+    NVAPI_DATA_NOT_FOUND                        = -121,    // Requested data was not found
+    NVAPI_EXPECTED_ANALOG_DISPLAY               = -122,    // expected analog display
+    NVAPI_NO_VIDLINK                            = -123,    // No SLI video bridge present
+    NVAPI_REQUIRES_REBOOT                       = -124,    // NVAPI requires reboot for its settings to take effect
+    NVAPI_INVALID_HYBRID_MODE                   = -125,    // the function is not supported with the current hybrid mode.
+    NVAPI_MIXED_TARGET_TYPES                    = -126,    // The target types are not all the same
+    NVAPI_SYSWOW64_NOT_SUPPORTED                = -127,    // the function is not supported from 32-bit on a 64-bit system
+    NVAPI_IMPLICIT_SET_GPU_TOPOLOGY_CHANGE_NOT_ALLOWED = -128,    //there is any implicit GPU topo active. Use NVAPI_SetHybridMode to change topology.
+    NVAPI_REQUEST_USER_TO_CLOSE_NON_MIGRATABLE_APPS = -129,      //Prompt the user to close all non-migratable apps.
+    NVAPI_OUT_OF_MEMORY                         = -130,    // Could not allocate sufficient memory to complete the call
+    NVAPI_WAS_STILL_DRAWING                     = -131,    // The previous operation that is transferring information to or from this surface is incomplete
+    NVAPI_FILE_NOT_FOUND                        = -132,    // The file was not found
+    NVAPI_TOO_MANY_UNIQUE_STATE_OBJECTS         = -133,    // There are too many unique instances of a particular type of state object
+    NVAPI_INVALID_CALL                          = -134,    // The method call is invalid. For example, a method's parameter may not be a valid pointer
+    NVAPI_D3D10_1_LIBRARY_NOT_FOUND             = -135,    // d3d10_1.dll can not be loaded
+    NVAPI_FUNCTION_NOT_FOUND                    = -136,    // Couldn't find the function in loaded dll library
+    NVAPI_INVALID_USER_PRIVILEGE                = -137,    // Current User is not Admin
+    NVAPI_EXPECTED_NON_PRIMARY_DISPLAY_HANDLE   = -138,    // The handle corresponds to GDIPrimary
+    NVAPI_EXPECTED_COMPUTE_GPU_HANDLE           = -139,    // Setting Physx GPU requires that the GPU is compute capable
+    NVAPI_STEREO_NOT_INITIALIZED                = -140,    // Stereo part of NVAPI failed to initialize completely. Check if stereo driver is installed.
+    NVAPI_STEREO_REGISTRY_ACCESS_FAILED         = -141,    // Access to stereo related registry keys or values failed.
+    NVAPI_STEREO_REGISTRY_PROFILE_TYPE_NOT_SUPPORTED = -142, // Given registry profile type is not supported.
+    NVAPI_STEREO_REGISTRY_VALUE_NOT_SUPPORTED   = -143,    // Given registry value is not supported.
+    NVAPI_STEREO_NOT_ENABLED                    = -144,    // Stereo is not enabled and function needed it to execute completely.
+    NVAPI_STEREO_NOT_TURNED_ON                  = -145,    // Stereo is not turned on and function needed it to execute completely.
+    NVAPI_STEREO_INVALID_DEVICE_INTERFACE       = -146,    // Invalid device interface.
+    NVAPI_STEREO_PARAMETER_OUT_OF_RANGE         = -147,    // Separation percentage or JPEG image capture quality out of [0-100] range.
+    NVAPI_STEREO_FRUSTUM_ADJUST_MODE_NOT_SUPPORTED = -148, // Given frustum adjust mode is not supported.
+    NVAPI_TOPO_NOT_POSSIBLE                     = -149,    // The mosaic topo is not possible given the current state of HW
+    NVAPI_MODE_CHANGE_FAILED                    = -150,    // An attempt to do a display resolution mode change has failed
+    NVAPI_D3D11_LIBRARY_NOT_FOUND               = -151,    // d3d11.dll/d3d11_beta.dll cannot be loaded.
+    NVAPI_INVALID_ADDRESS                       = -152,    // Address outside of valid range.
+    NVAPI_STRING_TOO_SMALL                      = -153,    // The pre-allocated string is too small to hold the result.
+    NVAPI_MATCHING_DEVICE_NOT_FOUND             = -154,    // The input does not match any of the available devices.
+    NVAPI_DRIVER_RUNNING                        = -155,    // Driver is running
+    NVAPI_DRIVER_NOTRUNNING                     = -156,    // Driver is not running
+    NVAPI_ERROR_DRIVER_RELOAD_REQUIRED          = -157,    // A driver reload is required to apply these settings
+    NVAPI_SET_NOT_ALLOWED                       = -158,    // Intended Setting is not allowed
+    NVAPI_ADVANCED_DISPLAY_TOPOLOGY_REQUIRED    = -159,    // Information can't be returned due to "advanced display topology"
+    NVAPI_SETTING_NOT_FOUND                     = -160,    // Setting is not found
+    NVAPI_SETTING_SIZE_TOO_LARGE                = -161,    // Setting size is too large
+    NVAPI_TOO_MANY_SETTINGS_IN_PROFILE          = -162,    // There are too many settings for a profile
+    NVAPI_PROFILE_NOT_FOUND                     = -163,    // Profile is not found
+    NVAPI_PROFILE_NAME_IN_USE                   = -164,    // Profile name is duplicated
+    NVAPI_PROFILE_NAME_EMPTY                    = -165,    // Profile name is empty
+    NVAPI_EXECUTABLE_NOT_FOUND                  = -166,    // Application not found in Profile
+    NVAPI_EXECUTABLE_ALREADY_IN_USE             = -167,    // Application already exists in the other profile
+    NVAPI_DATATYPE_MISMATCH                     = -168,    // Data Type mismatch
+    NVAPI_PROFILE_REMOVED                       = -169,    /// The profile passed as parameter has been removed and is no longer valid.
+    NVAPI_UNREGISTERED_RESOURCE                 = -170,    // An unregistered resource was passed as a parameter
+    NVAPI_ID_OUT_OF_RANGE                       = -171,    // The DisplayId corresponds to a display which is not within the normal outputId range
+    NVAPI_DISPLAYCONFIG_VALIDATION_FAILED       = -172,    // Display topology is not valid so we can't do a mode set on this config
+    NVAPI_DPMST_CHANGED                         = -173,    // Display Port Multi-Stream topology has been changed
+    NVAPI_INSUFFICIENT_BUFFER                   = -174,    // Input buffer is insufficient to hold the contents    
+    NVAPI_ACCESS_DENIED                         = -175,    // No access to the caller.
+    NVAPI_MOSAIC_NOT_ACTIVE                     = -176,    // The requested action cannot be performed without Mosaic being enabled
+    NVAPI_SHARE_RESOURCE_RELOCATED              = -177,    // The surface is relocated away from vidmem
+    NVAPI_REQUEST_USER_TO_DISABLE_DWM           = -178,    // The user should disable DWM before calling NvAPI
+    NVAPI_INVALID_CONFIGURATION                 = -180,    // The requested action cannot be performed in the current state
+    NVAPI_STEREO_HANDSHAKE_NOT_DONE             = -181,    // Call failed as stereo handshake not completed.
+} NvAPI_Status;
+
+/* Initialises NvAPI (must be called first). Returns NV_OK if successful,
+   otherwise can fail for several reasons (not using latest nVidia drivers,
+   don't have an nVidia graphics card, etc). */
+extern NvAPI_Status NvAPI_Initialize(void);
+
+/* Unloads NvAPI (must be called last). This unloads nvapi.dll so forgetting
+   to call this will result in a memory leak. */
+extern NvAPI_Status NvAPI_Unload(void);
+
+
+/* Sets pIsStereoEnabled to true if stereo enabled system wide. It will return
+   false if 3D Vision is disabled in the nVidia control panel or 3D vision is
+   not supported by the hardware. */
+extern NvAPI_Status NvAPI_Stereo_IsEnabled(unsigned char *pIsStereoEnabled);
+
+/* Creates a stereo handle from a Direct3D device. This may be a D3D 9, D3D 10,
+   or D3D11 device. */
+extern NvAPI_Status NvAPI_Stereo_CreateHandleFromIUnknown(void *pDevice,
+	StereoHandle *pStereoHandle);
+
+/* Destroys a stereo handle. Call this before unloading the NvAPI. */
+extern NvAPI_Status NvAPI_Stereo_DestroyHandle(StereoHandle stereoHandle);
+
+
+/* Sets isStereoActivated to true if stereo is activated at that particular
+   point in time. This can be toggled using the Activate/Deactive calls,
+   pressing the button on the front of the 3D Vision USB dongle, or using
+   the nVidia hotkey (Ctrl+T by default). */
+extern NvAPI_Status NvAPI_Stereo_IsActivated(StereoHandle stereoHandle,
+	unsigned char *isStereoActivated);
+
+/* Turns 3d Vision on in the application (as long as it is activated on the
+   system and you have a valid handle). Note that the user can manually turn
+   it off via the USB dongle or hotkey so you must constantly check if stereo
+   is activated. */
+extern NvAPI_Status NvAPI_Stereo_Activate(StereoHandle stereoHandle);
+
+/* Turns 3d Vision off in the application. Note that the user can manually
+   turn it on via the USB dongle or hotkey, so you must constantly check if
+   stereo is activated, and turn it off if you're playing 2d content. */
+extern NvAPI_Status NvAPI_Stereo_Deactivate(StereoHandle stereoHandle);
\ No newline at end of file
diff --git a/nvapiwrapper/README b/nvapiwrapper/README
deleted file mode 100644
index e75e751..0000000
--- a/nvapiwrapper/README
+++ /dev/null
@@ -1,7 +0,0 @@
-'nvapiwrapper' is a wrapper around NvAPI, the proprietary-licensed nVidia
-wrapper. nvapiwrapper wraps the nvapi.lib static library (which is a MSVC
-binary) into a dynamically loadable library (nvapiwrapper.dll) that can
-be used via MinGW. Compile nvapiwrapper.c with the MSVC++ compiler to
-output the .dll.
-
-This is only a temporary solution and will not remain here permanently.
\ No newline at end of file
diff --git a/nvapiwrapper/nvapi.lib b/nvapiwrapper/nvapi.lib
deleted file mode 100644
index c8e9617a3c6e218b6666cbab05d12d856632d183..0000000000000000000000000000000000000000
GIT binary patch
literal 0
HcmV?d00001

literal 81968
zcmeIbeSDPFng1V<Py}2lBIZkJL27MUEs01mKD3Z0AUwtdVoGVlBpH~|VJ1!{7|_at
zEk$vw_3N?}-D0s1sdWqW*Y%aPR)ls(THV#!mSw41E!+CdT3V><_Lr@0`F*bYI_GoF
zWCreG|M~s#C9OB_b6wZDuFtv8{WSN?J#*;|k#tAw<D)C4=KfuEb>++%SIxTS>dIWZ
zZO)o;%}3R<YII3S$@fZ1DmR_`@7y~0zhN7gy{0X>F47fm>xd*0P0>tGIyq;~)s3^N
zTNk!1ylH0Jl6BRM4Q<VtNT#QI&YU?bs!MWuz>&__4vp1q3v(i3i&LFFiKzIim(Ool
z(!8vCNo{>w+nhOGnnah@xUnaiUf+<+MANGy9YLR2)s2u5WK@momPOiax+N_ltYulv
zBFScS)~2J8OtdcE-Ia)}pPNptU7oDYWFj50Xs0pS$hxcRu5GJM#3S9!Jwd_h?q$(l
z3_qF^(G*=1?}ntNXm_e7-I42T&ZMK6j#yK)BU9g-(`|V&efo}V^P-vBo^(2z%rq}*
zkX7raZEKEZ<~BArBs=3BkxVL`>u+dol<w8t-KmZ^I(E7NE?F1vj7Q8c=SPyA376J%
zGtP$2n)L>kMAqg-&8ur@Ovl$o(l)4}lY=vf7N?SNXseBMMcU(ucqSh0W=K<Wn@&S@
zS64#D5KkrZosH?#>bR$ny_%!l-9viRMHA6X^fc+zSs-1G11mKXPp<KG)J3~9>D2lH
z_3D#7YrSeYLkoQCBJqT5i6(19XJ|-EB+-+*jwF#$o!8ss&9TpoCp$e+HS2Sx4y#WB
zOu~GpY%^{;8j`D1{;GhtCej@(uoB&-IxmrGk0c6*EGaw`bT;t?3Kp0V#B+_x&O3C3
z&MzK`@U~2>fkmlEXQ5T++ojjsAsZfcZfwla>O`V0x;oO6$mFbe<255O5&qgM7*Jq%
z&5?C>i^(bA+n1$=ibEoEusH1uAmlXb8J?j+;@z_4&c6vsyHjb71BcAE+EfDjbSjD6
zB9Y^e>6@FzIv?V!Pf9K$Z*i(S67N`+>Oz(^>urAx8Cp&@{za)ZI65TeH7@7c5c3%h
zW6tf4dIgVn!M+t+-#s)xY6VBnd5zUw(X@ZCx1Nqnd|h;DPo}HKZ3NbrNECL|q$24~
ze+xGqYI?fe_UUZRiBzVLecAdh9*RvgR(BF7muP3<!b9CR#WS%*@y?tx#?VYS<Afx0
z5ogM$=dbE{jZNO^%NA2-V{JoyUFx<Z4ztn7+MD8?nV8)wOkmymWMpl;qp@4gf!(qS
z-Fei6)YsNxn5*M!deXs}q`-PcNPRk;N*8v?+Q3A3M?9OkuAy#-p1D1Vgn!U6k@%;;
z<jm{psl`#FHr12N49PRUuC}qcr>iTK&S?1|{)VO-hgft@3RJ;LZ0N+5LVR^Rn&ysT
zgf*INJlHpDdRDKFrkmp%hHgd8>v09Mwm|M>xG-vpMmoI{qe;9h7EP~>B+Rj6XxWzb
zc&dA8{o<zRy10L?Hk||anS3o62~P32e9Euf632cSNt|IsINU}vr<-#q9=gT&Yg*hx
zrX6SIcqcYLoq^ia+V*%d=b8m)9e2594mTR??Ztk~8IE8%xpLxiHai~j3m;RF#ptL@
z<8YNW>yrbeyAc~;&X$ki%bv0r*I1D?Zaax)=GQH5Fk9@94!j~SJZsU6JC4h_)d=&n
z<ofL<i*3b=@vM?0@9<tYw7YOYFIf=b1bAu8V56NmtJu4am5UACg`=G<@#t-CCx~X8
zzPv4C$UL^xBqGUMf@4IKCtIYJjGh{4x<g;Xj9S?(tsl*s(sB19p#j(4acs42N7pg5
z<(!V?L~Jt{KkAxubz!HOI}sy?uI`%k*w<2t9{&p7rCN$DFA?cl6ki*6=St`1%9C3D
zHswOZGcTR$=^COFduaikOXn?WtM8TbHeOXm?UfqFWP2A5K(fLCr|s$WX#PZV@M<j<
z?}F7Ih4GkG*3c=NBF+faNpr4t#|9f2?5gnBq$A0W*pPkJ1m$M%Ht)Q2IL{+jU8>`j
z993L%x|U@PC%mgM48kauLxWu}ur@_kr=#65Iho76rsJJFI>761t)}U=)@Hmsj;7kG
z<<iN!7BFVKM3n2S1zpiK4Qst)POiH#S=bxAoX<J`n+siiU7lXQFv=@Un=$C4uYY9)
zHY`uxlEhUA2di@HqLIRa>!KaV&@Gp`SP^TYN%x}PRIm}v(XNPIl;q`>*Q;kITVJgf
z>Jz+l%&QQ*cFld2Z{_I~{*WGeY#3sc1Hx&C31|I!ykI%aAmN^y?&;3prE=%Z_*Zty
z{Pd^o-jEDi%{JonDZ1@8$3vxA1r6Og+@W?{l;F}Ms!=t#Z-LSKFLq3KY~saEgod7G
zLxD4F6(M9vN-pm7KFN?1v(uBm5|$?uc)4rWcuT|5w%SChn^PbLc^Om}$wcO+a53kO
z(RAVRt;5}vu;%9Ynj|j3^83iv(p>9T6ib0yK$1yZ!FBtP_<51FYa>H!&FhmL*#0Bj
zl_fy~&fR#$xd=x%*|czB)`iP5yxjCVH*`1kB$M7%r1V_c73JP8?cm1Z&?BKZWb$$c
zq|=F48-5WO^HjrDP&F?1-ElRj5xo4!Nta3Sgcn3$^t!g|aMb9?l$`bZ7azU0@>=`;
z#W1{qv8gh66Qg9<x&QtDum*DOkDt4ve(sJs4j<?4sGqx|j(4l-aFbe2jCz0UwD)rn
za_){gZms3sa>prm=vz4copXDNm38df&)reaxzCjQlHuGPb@Rrtxpj$4)|?yeXSxG!
zL*4yyy9o|W<|59N@7x{rb9dCwbl3b$zLs-$)N$*nGv`P*<WB4v-=)ME*W4F7cSpUz
zE&OwL)aAoEatpy8;@wT`0(YvN^V}Wv;JzR(-Rz1xcSjwcraN~>ou4ZV-a9yVM_t}Q
z!AU6Wb}>To?*!YM-skS9%UZ<Fb?%OO!F$vHH{Veo@<>3~69F@4*e3;6jc!ZzWGZgL
zhbvRJbysxa9i&7GZ$ek}R?VtNu1my|x3u9+!s)5@n@cL}0|lnDtun*howqr!s;rzf
zYu41Mv#y<a?Nxzs)#ydTMwWc(hfgp5`!`BTeu{he@;ALRjrRlAMYV-CV1(S@_y0zZ
zLtM1IXU%2J*8FY2j3IGzO2*Yp$LCxkHVFTAjVdX5EiZ1)v(wYLftMn-QJ#$O{^pca
z&Y9lc-R+r5#`z7yn@TF5ou0ubt3BU!_mq^}ihSRCP>l~k$JCO>RTXvhbE}sxTDGX6
z=DKM;J@L-ziFo_8si!dyN9Sb8`9X>`wb!leT-Uv_Yv#)Ko_L~jW%q3>)6vArHC;Vz
zo#}Ne(=)EA3>Iybl`A`gcjCKO2A?Tk+1+`|N}1x7W{OvGidSNa5#&#CRmnx;hN1At
zk_$>kmz0jx<)w?`9qCkeYISC6dDDlcF73+TGZ7o`uGCa{*9sptO_!A1JK`e=y9&NG
zyOeAFCttnszpVXlAG`cRmM{3(_jg%d^}sKuTAuR2<G-=|i8ubA`Ibli)rpywBfl$a
zwEX4u|J7mn#jcBfZ}}%94*#v?8Gm|IHksgW<`)ls)bbPOm43r=>Gp3-vwZ(QZ)4rR
zoX}Bj?SEZ4@mrRc|Kjh~Sf26t19(SD|L*+XfAuex*ZjxQtmPH2U-T!-KS=)SX3Mkp
zu32UIf+PR+faPV|yB1o0=lh+HSbpr1EAae|{#AebpSZ3bJMWj&|M{DTKWAgUuypxn
zEdOYK<t3KS|K+BUmapA=?~9h7yJ5r*%P;JI>?zBshX(%5a(wzvud&?H`LO}Zzb^gS
z9LqmD_#@8O?l1iQpR7Ik<f|XC{GD%K{{zdHef~S|vHY9<*T@%sbo7U<{gP$3{@U{B
zqd$1u@>OrwGUsRhJMuMafAE7Nl9nI&Km*swcYZMcC2K$Lw{Oq2T=(RN6_(#$|8uU-
z-@W|HRo31zx|8eSAIAT(!rI^U+woivKmOiP9;@zI{FQ&SF&j>lR#~3-SHENaJEI%E
zYwhEwJiu-BSI?DRZ|zV1^G$jvfZ^`H`TN7x9{X}X=kcx4PyfQ&pWXQOYRj8%c=Eq3
zzqjh{=PjT7+>V`=uPR^mkmV&0&Nyy4@%2e<mVbI^?JJf)uyRbb<?lC*`lIE$?_T(G
z%Rjo|T^Y;&`TM(1T0Z{3x@RoU?7!p>mgn!DbD8BAfB$rY<@)-E-*5SfvHvjL@~;N(
z<2LrzHFt7*n0eL3*V&lZ-+qPKcKkBN?WFSQeN$}A%uA=#TYhx+$d#5`>qZ>4eEfLd
zk1WqTf8PSj3;*u$$1Gp+Z=YXe`I*N)^A*dr58d^;<vkmZ-EMi#cdq>3mjCWccW$?Q
z_kBOV!Sa{qJamiY4_+1JestbNKYFjVSI_@_o#ks@eh;_pKm0oJ7uNph{J(s+<%fC~
z{M7QhjxS+M<}Z&^^P}ktsI%#<g*+yV{MgTLw0(cl_t%$O{^o>fb1nbHi0?E0(O(U4
z`#=1(Jsiv8Z=PiSo0i|f?eo~ozuIc^{JP?w->^K;H--Dl#dodZHu>GB-W+9PzV?+X
zIL7;Lt^c;QUv<ylywCD~9DVPPEr0!UQ+Q06dVKn`*8U$mzHyu7f4TOLlP&*ZVBI$?
zPyhLYBP|cU_%GZ}Zu$PFcx;?-=hN@ln7apl$8|pVsbg1Idu-JuFIXNq<9r^UU;T%>
zS$FrT+aosSaOxk)-~8#fCR+QLT?_8C{M!4jdD`;ROTW$S<d@%^S8MIrh4Cvb$M2o;
zJImKyvS*{^CszOF_m+ph{F$39SKYP0+w#$CE4iK*M5b~dzkl}+rrVf*Jiq&S%gJXZ
zAGX}yv4_X=2lsvO6V^U6()K6I@2fi5Z26JZpXGWEE^elGCK7P!!*jXM*Oe^ae*DJg
z>Vx%vm+qlG?~h5QQy0tfQCV2W=>9*SI(6#bM-MA02||Lsps_&Ul<gNtzZ=!{T&XnV
z@2*3q{#~XqRzA=;Or3ZAaKzp9@7(p7cS?Fb<N~(`#hVKCzZd;aEq~{8&t^X0;(aB~
zigLeQ6}$JN&t1)0!FXbITR;AZT$34M=6nm|Exgx`eu7Kv=;~*;|K?Lac)|T)ecp9^
z>~r;l!FY9zGHcK1{&!>zepS}No&S2p%M@{U{oq}n87x7-e@nn!!5{}Q$Wj@^ZLT2Z
zN=|~$)xRYLetZ7*`nT?ScG%tZZ*5=v*7b|u`OK8<%ip@?<+0Cg86kfBA>fv0$7VML
zyZ>)rI?c>@1vp!IW0O$^<C|bt&h)!J7S!qaz=cniN`=oo+cPO97r7kSqY{t}oWpGN
zyMj^vHopA=ao)Z7o#*O<J;IF2W*`5T%TG4tWE-`;er)6R#iMS-7I4=ON8Me2+{RAY
zzWjI-#tQGr8*}=M+g^X%O;VozaZpea=$`-x^vi|0(=P$pQgK4RMjQRn?H5QpM8BU6
z`bRYe+OgGp+7}<c5%UK9CmUmae6IF_>pwXB1^TB#OQ2s~OgQ}#kS!G_^lP+R|I!Z8
z?`JD^{ri1#$B?)F%b`HmzZ_@-{qh3H>6d_PsW_ouqn&<fhv@gS6|3Lx6QX}66sUf=
zXbtqsi#DfU0<yssE%a-&(=Y81{eHG$_4|E7^v{6;)n5k)^verPr(XiHrQ(EsX_WLh
z{n8H6?`JDkzuzZB|Dr&V9Df=?fqr>$?DR`OHgH0}Mmzn|4$<#tD^|bXCq#cM^{=%0
z<psUdF9F$7aYDaFJN?oQ(eGy~R=?jTM1Lm~==Ku>1nXaJLOA^rkS!G_^lP-yzjpft
z(hkw@XM_H6IKq#`(Q;H%a2y?*a~!Qd4)0s=;=JMab7ROm{&Ycs>dycI{c_{P>6d_P
zsW_ouquu(Kc8GpITe0ik@8h%=JpSJS1*(4&AkZ&2dz^j=$d-x|`Ze0=mv)GLKU=Z-
z{XQZ3w?TpGzZVebmm5@0zXW7U#R>fy?et4KM8BV{Sp9yV5d9BAf$HB02=vQMHK$(!
zvZdmLevNker5&Q*&sMB{zfXw%N1#CUe-#kumm7gjzXW7U#R>h=;PD^(ue3w-``Mts
z=>6C4=f;q?|2`fllH>nAP@rFKUON2}kPV#BuhDM(OFKlrpRL&S@Aq-q3+})D)c>^A
zFE?DBehJ8yiWB-Z+Ub{eh<-m?vHJZ!A^Lv^1-ktl0tD+{ZW25F5|AwwC-iHy(=Y81
z{eHG$_4|E7^uGiJs{dzzK)>ABcKRhCTPjZI*J!6-+9CS=Y{lyL`-JF!1qxLEYk)w%
z+>CenB_LZWPUzQYqaUwdq#dH)&j$UWuV4K5T<rz7{{bja{l@`;et84I>6d_PsW_ou
zqn&<fhv@gS6{FveFGBxYP@wt;0fByb)5GbPfNZHap<koj_9N{O{eHG$w;#Vx?ilip
zpLjIJ=$H2t1O4(wjngjy*-~*rzeXGVx8i03%pv;yY|uXeS7_sKg*FzicFndlF6SD~
ze=Y3y%^inqOY)aDp0QA*^Dzz-j7Q#Va^sPJY^gXg9*uVMA?=Xy_}Pk`55G_DIP&zD
zL4oR@3<~ti8)Qzu1Y}Fa3H=&v^y7Ri?GXKbHs~+<eC+pgW60Bg85F4ga!{aO-qdsY
zB_LZWPUzQYr(fD3`u%KYqu=j$2K|*#p!#Qm0{!wvq|+|}*-~*rzeYR#(hkw@XFD7H
ze!ny5zX1wV{~S=DU*0@*`XwM+Do*IvXt(`KJ4C;qt=R3~@8h%=+<)gof$Cob3iQhx
zzD~acWJ|>f{Tl7`OFKlrpRHK^exDHi%b-B@w}Jxw@+P&@F9F$7aYDaFJN?oQ(eGy~
zR=?jTME@!%Q2m{tK)<}P?(|DQwp5(ZuhB+7t|z1&qTkO3{h`+retfR>g4<653RHg=
zD9|q-25|Z%AX_R<=+|hcU)mx1{cOeP_v4Gu-wOq*{|-=~Up~O#^h-dtRGiSS(MCVc
z$I=eb?`MPlvpOI9ee=gsa6Uc@MLM2sAe|3<2*Zs>0<xvz#CSB?jA#A!3#1(~9{EUz
z&4%$z#`Q%Rt}iCw`eMkrtt{s{!@pPL=g1vb-udl*DAMsf2nxm{A0)8~Mm#D3*-~+0
zJQ{7rgZDe69Wow28^%-A`yGCt5d9BBf$Dz*6zG=^zc~F8kS!G_^lP-!FYOThezs!u
z`+Y+6_d$W`e;gF(mk;bX{SuHZ6({s-w9_x`5dD6(V)grdLiB$Z3RHhTD9|q-GIIJQ
zAX_R<=+|hcU)mx1{cOeR_xptCe-;W<{|`Zde)(XO(=P$pQgK4RMmzn|4$<#tD^|bX
zCq(}XP@wu>0tNcz!(2|k1Y}Fa3H=)F^h-NLzn`sG{eGVi{YRic^}hlN^veg(oPG(&
zmWmVlHQMQyc8GpITe156J|X&l4F#%y02Jt#56wCK5|AwwC-iHy(=Y81{eHG$_4|E7
z^q+(R)&CYK&@UhKbNVG9TPjZI*Jz_3ug|0%qTkO3{X@=Sr+>f0@8`ylcm8?@3RHi|
zaHC&7oappRK(<tz(67->zqCX2``OM$zu)f+`bR;S>K|+M%Lgi*ehJ8yiWB-Z+Ub{e
zh<-oY+35HCok9NuC{X=npkVuv4}m)U5|AwwC-iHy+y12;qTkO}?Dp^XaoP)B&rO8_
z)qfc%&@Ufcb^0YBTPjZI*J!6-+9CS=Y{lyL`-JGf5(-p*B`DA@AGUS+B_LZWPUzQY
zqrYeS1=0@D?`MPlGF*>N!1d@jT#tI!auaf{Mg7mN`2BOoQgA-1ph(Aa11K1ed|=p(
zM*^~?;>36~+RcZwL&oE0D|SBoKDlGaJ08_Rf$E<R3iQi|oSl9N$d-x|`Ze0=mv)GL
zKU=Z-{XQZ38=*k;F9QYo<%8KyzXW7U#R>fy?et4KM8BV{Sp9yV5dABmK=rQz1^VT~
z<W9c?WJ|>f{Tl7`OFKlrpRHK^exDHiF(^>|2~eP4J^=6ZOF*_%oY1e)PQSE6^!wS0
z)$jKS(Vu|=)!z#W^vj3#oqh?(mWmVlHQMQyc8GpITe156J|X%yL4oT3EGW<~4;ncA
z5|AwwC-iHy(=Y81{eHG$_4|E7^xq2ws{ejapkE%2aQY=6TPjZI*J!6-+9CS=Y{lyL
z`-JG<2?eVEVNjr79_VoTB_LZWPUzQYr(fD3`u%Lh>i7GE=>IAdsQx}spkE$Barz}7
zTPjZI*J!6-+9CS=Y{lyL`-JG<2L-DCyP!b7JUHX@OF*_%oY1e)PQSE6^!wS0)$jKS
z(f>3QsQza`fqr?|$LW`VY^gY*U!$FVX@}_dvlXk~?-Qc`5EQ8X7eIl2c|ghOmw;@k
zIH6yooqlPD==ZY~tKaVvqW@=5p!$!10{!w(mD4W)*-~*rzeYR#(hkw@XDe2}-zP->
zYfzy2e+>%s%Y$G}zXW7U#R>fy?et4KM8BV{Sp9yV5dFuYK=q#l1^VUTHK$(!vZdmL
zevLNz@p@j`A^QDn&|mcHdB2|<L*DiCAQY(ncR+!DdEn0Jmw;@kIH6yo-TIeyh<-m?
zvFqRO<Fpri{W9V_tA7+I&@T@OI{gxW=LfKaevNker5&Q*&sMB{zfXw%aZsS^e*!4b
zFAp|4{StuZ2e5>GjW+t_`2m<i^!wSMKlJ@FKR#D`!Sz2G3RM48P@rEP#&r560M8F#
z3H=)F^h-NLzn`rb{eFBA`pcm}^<N1J^veUJPQL`;`2j4UU!#qFyk92m5dD5O=s&CX
z%ly9iV<|WvGoeVwQw0jfBM-s4@kjukC%_Wp(P%dwX@`u*&vv%s@%t7zo;gsY<EaA$
z<B<n>-FPGb&lg~c@o2Oe500<W4jGT14dW^L`0Dp_W63+dE`kEp-v|oy%frV`zXag<
z0xY3lqn&<fhv@gSosE9K-x>6`LV@aE2@3Sf1Jh2w1mO7sETLbcjefjeDeVybem3a$
z?s1*|`7FPW(_V0Y=!62*9|HyY<somUUjp!a0hZ9O(Qf@qJ4C;q?QGV+-_MO9Z~N(j
z0@a@Z1^VT|bf;ee@O%N5(67-(KaNk*4$<#tgZ{HRKKXs!7-SyoU*34`fFd2wCQvXQ
zdAQz<M*{G?0hSn#M!WftcF1`AY-ckcem^&sJpJ3CK=t1X3iQht0yzB=faeXcgno^7
z^C9gJ{eHHyoe#gS8-tw-`8RJo4?>ZSXD28ak9?_t8;=Cw`2#F59*uVMA?=Xy_}R{8
zKKy=eEP47LfdbY4RZyT`zKFr;mjFC}fF<;6w9${_le9zh``MtssN<90$7wIP{vU?|
z)xQrE=$9{#aQY<x&mUk3{Tl7`OFKlrpRHK^exDHi{ZOF#p9Tf`<qI#IehI+y2UtSC
zMjQS3e2%n3^!wSM|9|xP96v|Mczy^)I-WzIU_A1r9d0}lfaejg#CSB?j0f-UNIPUa
zem0Eftl!`9`{$0O;P&+r6zO<=1`5U_Up(T*BLR3m0ZWWWqs@45{*ZRac>HV_&sm*6
z{J!~PDL9^2ph(B_8Ymc#e0ho+j|AX(1uQWhjW*+v=M`WM8IPY0;|YDe<j3caA@6uK
z00pZ5I4IEnQ+(lz(=P#dUI9z!*J!tWNjpTppY4CLefj;17|&Z!q~jR`1>=z~t#RX#
z06f2dCB~!CZa$<PG9Eu$G4tWa7oopogw;O+6zG>P+Hv|N0M9RA3H=&v^yB;??GXKb
zHs~+v{NeY>9YfysG!_bU{f`3$`sK@koPG(w^9oo(zec<DFYOThezs!PzaO8gz2N>_
z1_i2rGAPh5Uufj?O8}l%z!Lg3+Ub{eh<-m?G5Y=ZBJ^Jd1**Rs6zG>PVRHH<0M9F6
z3H=)FwjXJS==ZY~yZ!ima>tOj{ZvAM>YoV;^vf4VIsFoV=M}JoevNkPU)mx1{cOdo
ze?LA~d%^AJ1}ISdb3lQ9`LZjgUjp#F0+!IP(N4d#L-hOEiqY@K7omSX6sZ11pg_NT
zL6_4n0eD^kOX$~VqaXJ-q#dH)&j$TP-{0{2xpCxeKg*y%^|yio{qm(^PQL`;c?B$?
zU!&djFYOThezsz_f4`5@UU2(a1qG_V6BOu|FG6$rB>>MWU<v&iZS;Q{&nv(jqTkOp
z3g0=9^T8eeL*#xSMdz*W1S+cDE>NIXzO2pZl>j`SfF<;5w9_l?5WRl3GwSsNPp`KZ
z6;<yYpg^yDp`6nz0eBt(OX$^TqZij}(hkw<XDep^^y4X8HjUsfZ+(9j3RM3#P@rGF
z1kdT006c$yCG=~w+rFh8qTkO}?Dp;V$sI$U{`;Xo^*;y-^vf6bIsFoV=MAugevNkP
zU)mx1{cOdoe?LA~yG%fy{)eGJ^*;g%^vjnGI{gxW=MAugevNker5&Q*&sL0nKfVb4
zeNdqK9|r~c<qHy>ehI+y23SJBMmzn|4$<#tD@MN`UxfbeLV@b<2L<}&OC6nl3BdCP
zSVF%>yX{}vA^QDn#cuz8pWHFzZ9mUKf$IMuNVk7{5v9{F0eId3OX$~Vr(fD3`sHga
zZMI_d`+Y+6zW@cQ|0PhMU%oukRvhuD1mJlCETLbcoqlPD==ZY~tKaVvqW=gKsQy<#
zfqwbIPp4l3@Vo(*(67;M`<Hfzem`3=+rJ;5tG(dy=hsl6`UgOPe)*D8r(Xi_yaATb
zuhCAwv_tg!*^1Hc#}}dhBowIrw?Ml6<BL_DehI+y23SJBM!W4t+9CSoYg%o#Vz(c^
zPwp7<_TP7)K=qg4n*{^?@@25L;)q8j0M8r13H=)F^h-NLzn`sG{eGVi{iEdj5QFd6
z8*BB;7uY)e5`gCoRKG^M?MK=n`u%LhY(IW{uJ(f4{{$#d{bitF{mYl`I{gxW=MAvL
z`qyZuU)mx1{cOeP_v4GuKNSj8|7D;+zkE@!(=P#d-T+JJ*J!u>NIOKopRL&K$M2In
zhP>_nN+?kMm7qYse7UjHF9CSo088lCXs2J=A^QDn#p?I_gy^q=0@Z&5D9|ro$n5k>
z0G=<v68bgT>6dnhem`5W`u#p3`s<)T_0I<d`sGWcoqh?x^95K!zec<5U)mx1{cOc-
z|9*U~_JaFwBNV9qWuQR6eDSr@F9CSI088lCXt(~Q9irdQHtL?@?r-{ia>tOj{jY=q
z)xQc9=$9|+cKRg%&lg|`{Tglb<NX+Ehv@gSVf~-=`!Rn1+_4m#j~Eo`coLvsJo1I(
zZaflz=MAvLcr@D0hqOb+<7X>&fAIU{jv;S8GEkuUdqIJI`I2;}Ujp#F0hZ9O(N4d#
zL-hOEiq-G;3DLg^3RM4RL4khxVt1!s0`R;6me8-!MnCSiNjpTppAGtpzTf8eb7RO`
z|Mx<H>c1Zp=$9{}clsp&&l_L~{Tl7ozqCX2``L<J|9&5*z2Nr06AD!S!=OOFe1X2x
zF9CSo088lCXs2J=A^QDn#p?I_gy{b&6sZ0_P@rGF^xx^106cGiCG=~w(=Y81{eHG$
z_4|E7^zVZL)&E^kpkIEd!0DF&Ja2#{^lP-!FYOThezs!u`+Y+6KMe({|5;F=Uw&M{
z>6ZXJZ-6EAYqZlZ?GXKbwqo`BeM0mff&$h50w~ZgKM3LUO8}lXz!Lg3+Ub{eh<-m?
zvHJZ!A^Lv?1*-oDNVk9dh=tQH0eId3OX$~Vr(fD3`sF7vY_?+c`+Y+6zXk=W|JR^E
zzx?oqtvKRQ3BdCPSVF%>JN?oQ(eGy~R=?jTME`LpQ2i%Cfqwb15T{=P@Vo(*(67->
zzqCX2``L=s@AnDOKL`b?{~b`EUw+`k>6ZXJZ-6EAYqZlZ?GXKbwqo`BeM0n)kl!QG
z-zxwG`sGJioPG(w^9EQ#zeYR#(hkw@XDe2}-zP->I4Ds46F`A}`5_snUjp#F0hZ9O
z(MG>KZvb<Mem@)Zhkky>kI&U!@cLmg6sZ2Gpg_O;_>I#q0eId3OX$~Vr(fD3`u%Lh
z==bA`&|eM(s{cw*pkIEl$LW^<Ja2#{^lP-!FYOThezs!t`|(BSp9ux3zX}xSmme8&
z`XvC*7hnnf8g2CB^JLNv(eG!2{<Hc#ncp{mECsixIZ&kIsRIS$ksnHO<B<S7Uw|dX
zqtRwO`23HwL&oE0!+47N{Ey!!cN}@I2Npqr>Td)E`sK%+oPG(w^95K!zec<5N!lU$
z{cOc-Pkwx^_JZrb6$(`UN>HF*evr!PmjFCpfF<;6w9${(W6}=M?`MPlqF;~s{oFY6
z)_*4ysQwrz&@Vrt<@8Gco-e=>`Ze0=mv)GLKik>p_xqhee-{*}{tPJ4FF*X{^h*Gq
zFTfJ|HQH_e(hkw@XDfF5_xm{Q1-G9&pg{F+0tNcz$I6_33BdCNSVF%>yY(;a5dD6(
zvswRsKR1TF?PnVlsQ!CFfqwacHK$(!@H_#Q(67->zqCX2``OM$zu)f+`X7V>)xQ%I
z=$9XbbNVF!&ktY;{Tl7IA8Ci^_p=qd{rG*H_JZ5bBT%6FzX}TU%MaN({StuZ2e5>G
zjW+smJtXZA{eCv+54|4p<8!qa)c-gXsQ!JRK)?L>p3^S@czys&=+|hs{-qtF-_KU;
z`uF?fjv;UR?}q}_|1>DjFFzRQ^h*GqAHWj&HQMQyc8GpITe156J|X&l2nDMD5Gc?u
zKXT~wO8}l1z!Lg3+UUpmOWGm&{cO0uKCbbe;(ouz@8`ylxBg#(0@eRBkZwQtVMeE4
z0`PnQme8-!Zv9I;M8EvZqs><A`uF=d?FG00SD--kzXl5Q%a2LgiX$GC06Y(XCG=~w
zTmRAy(eGzFoAvMab7RO`{{v8<`j3MG{qh5tPQL`;c>pY-U!&dnmv)GLKU=Zy&-i_u
z_JZsGEhtd^gP=ga{Aj1sF9G=cKbFw1(MCUxpVAJ|?`JFK`02;zYA>k2<Xu+(2vDG3
zerVL`mjHbJA4}-hXs2J=A^QDn#pw6ri_kw73UvLC0|ol!$5EYr3Bc$7v4nn&cKW3q
zqTkO}jDA192>oSHp!z3+0{!xXu1>!M;Pd}jLcc~k{n8H6?`JDUzaL+O{>z|1^_PPJ
z{qiHUPQL`;^Z!^vzeXGVc>O5t5dD5O=r8K^qu(cY40*?&N+?kMGeNrj<A-ydehI+m
z|FMLAjduE_9im@;hSz2*R=?jTME?y?p!(;40{!x1zqaCtM<oEC|Hl&gHQMOM`B&N@
z`u%LsU-auozn>dJ-uj;p1*(4$D9|rIQ0(+e06zbZCG=~wTmRAy(eGy~cK!Q(oc4mp
z&t*`c`ddMPe)&;lr(Xi_`F|{-U!$FVX@}_dvlXk~?-Qbb6%?rcPEep<ehAv>mjHbJ
zA4}-hXs2J=A^QDn#p?I_gy>H|f$Hx91^VU3tDSxc!1DlDLcd14?O)m<`u%KYv;F)1
z+!*q<|6V9i{da%@{qlp`PQL`;`2Z}TU!$FVX@}_dvz?88zuy`3e-;W<|29ydUw$Oq
z>6ZXJAAlwFYqZlZ?GXKbwzJXi_dA3B`=LPfKL`r+%MY77{StuZ1F(dCjduE_9irdQ
zb~gI`erM4CFchf%M?iso`7w5<UjnkF;)H&UHu`b?m3D}JKO6KHb^i7HIPC?GpM6lE
z`X2`c`sD}Yoqh?x^8r{wzec<DFYOThezvn&|9(F=hP?gvyHKF|`$2(z`O$l)Ujp!a
z0G80N(N4d#L-hOE&PKoA?+p5%g#y+8Lr|bUe(#juIsFoV=L4{WevLNz@qUK1L-hOE
zp#QAi&+z-YG01jg|MKSJ1t`+-yaWoybKNC-HoEah0G=1X664WmGah_iPTC>k@v~t(
zXZ?9OzkmLi^2T!nigY}$fP(QnvHCZ^cjJ)&JU@UX#-q`0exw~T9zWaJ&X3<We=IUb
zdE@yt6zO;dK*4y1zx<h-+;}7a&l6yY@o2Q$U!)x}9zWaJ>@R*lH<mp8C!s*~zXb~P
zSKYP0+v%48JWqfn^lP-64{3+!_p_bteE5Cc80@}Ma6aCFA{|f3C^Md;*H(J>uO$G_
z7r=?}Xtdj3q#ZIIKimIgfARb0k120{MnR~KXRIC1g2+_wd2|WD^9DK|jW*-K`B2&+
z<MFd$JVl)k{XV&4$kRUo3RHg?DA>O4-~EH>Zu^n|Ja2#{=0l_1{vquU{eHHy*+2Y#
zZVY+)r$T}1zYG-U|Ht#YpLhBt0M8p>3H=)F*1xnv^!wS0UH^U`r@i3*a3vI|{z_1w
zKl#k$!%n{h;CTZqp<kn&erbp3_p=qN-|rKmzX}Re{|%r(e|yIs@B7>(0M8p>3H=)F
zwjXJS==Zao&GzH>b7RQce(In=_0I<d`XAi)!B4pLF9CSo088lCXrmwZQ>7iE-_Hj9
zq3=ie@lLlrrsnBygaXyS3>4^}8EN~I(=P#d-T+JJ*J!u>NIOKopRL&K$M2InhCKZ%
zp+NPo0tNctS9P-4>6ZXJZ-6EAYqZ;bq#dH)&vrK3kKfOYAy0n{3RHgr6zG3s^=G~N
z*%E-~3$TQKjdtr_+9CS=Y{jmBzmL^^0d!8pe<MpS#&TRh@4<3%KvS_)@8zT_(1rMK
zWXZ>9s{=`|ktGdSN~Vz|OG&LD&C&*%6nLYw-2u`bUm)$IcQ;6Te2une8221)|HQbT
z(Kf)ilb{LsZ)C~aw4H|^LAofgoexs)c-r1W+hw$UgtlvFYXj-nVjvyICX)P6o!b5d
zG&ZRA@1!?D+V{UeI?7YDosTbdR#g{)RB07R^Hqa1-$K#~dfRD>ky50Mq#Yow(MLK6
z(rT}e<O`;??l62+l-3<XngmksG}_8Z6{Oju7LeABk?sU(-JK-)Vmi%y0Hk%FCmp5t
z7;W;^TpD+Rbc!?)529+_a#9UQ>#ijAg0${tkmlP?+C}dk+T<$&G;S|xKj|<?>&g?#
zO2hFXTCF>oR0Yzy)gaBckhFr{cG_a36lo)A2S}^+kq&~){F3AYy;^q|-U`&ZV@Q)g
z>YYYgIjMp)o74i*x-rrgkk);eBp)2m%m+YP_j%G$dXLd2Z?$UN3DPOjM7$8ty5*!A
zkeOdnFG%Zd25G+Sq+Rsxp-pb_Xxv`Xe$ru()|FR`O2cswH}gx93mdIl4bprINh|1W
zr%g@;8kZt%B<%ocwLVf7q;+2-4T7}pu=8!cF{DW#^-iO$oK!)YO=<yY-56;L$jmRP
zAEcQNfOH(slaA7RjJ5&N3DPOj#L>2HIjII@=9kn9(z=^LT6a5X7rlFE>m%(Y?I#@u
znfWCRA7krICRKs7ZZ*ivFKGq6?X<;6DbhyL4v?8&(m{}p_Z8A0Nb3$mQLQ_MGzp~M
zX|$D-DoC?QEg&<$q^%&W`v|EYq?r$Z@PC|PpC=uq_ZV#hq!Xl5q=~p3(YocN8jzV^
zQZGpBZU&({>f&nv4eg?L4{d#<y`=r5!yq%iq~U*I>rN(BfwXQlNb4>nt)RD^wiqcz
z+DO^~GV@D12r~0a8U$(GVYu|tx?@O_K<b@FTREwMG@H}{GV@E?0@At<llnoL`2a}k
zK2JJI?=jj2NGC|ANE2~^Y37&oagf$+CG~=|?q-mgU(zmm_t4fy+DqC`It()NOZqcN
z>z2LSQWZ$+R)fs^l2*{$PFswWB5fq?0GatE9R!*AB@KeK?y&K;?ikV}kb0-lR!*uQ
z%_g;g%>0t>0cqW@k`941^G`rJ-d~X3p!ZGM21%z#7b30py&R-<t4K{C{2zO0g0u~!
zb-xJGz7LTeqxT8g`bqmqFOpsdY2886L>SOO-AdAYkk-8sq;)?@x|!ZIZM~$8r29x;
z2jTyy(N8)I(z+)}qfk`qz8n8&-S?0_Oz#ZZsz|d*OG&FiTDO<91Eh8Lkq&|If9U%O
z{?WR>AiY8Fo3ss*<h8c;xDYQ=lr9Hp-6~QONb4p@+d$}!x?coo--k$#(fb5#{iOY*
z7fG*!wC*5j{3W*Tm8AI~t$QO#>wc1SGreirdPy5e_mRF1(z^Ymmq9w-<D^k#w(h$@
zTK7Gq57Rq?wkpzW(o)iDkeOf77eHFKk8}v6<NXOp>;8iD2EA|6Hb^=}y6}J5zL$f{
z{F0V{v~G;F4P@pQWagLj7`;!>)=%0`dXe-x$jmQk5?&B%-I=6Tkk*ZWwC*jW4fJlI
zZ5!!6(r(g|Agz0d^d?B_j>RnvrE-wgy$YmtuO}^_w~4k^QX45n+6vOTJ4sJ~wAu@#
z0g%@H14!$>O&X1xH0m7>Qg0b)3aNrL7o>GtNokPQy_eJn(#+ohY3A>deoXJnv>hS6
zN;*Lr`CePMj5GtJbr+FhAgy~VNbBBCx`*BeXxmBJP1;M!f^@t`NN<9)?%4NPDhFxZ
zt3X=!deQ=Vn`mn#wUJV!tspbMq$faTen|r$t@{U%)_t2adW!Xq2dTG=G=)?_nhP@X
zOG<;x{F3@WW`04M`Fo@v)B7@QM@X-dPLM`UwROu#GeBB*5h(^T^9$0tx0CLn_W{~=
zl6I5!lCmH(zoa)oT6gTFmdZh9enDFIdeQ=Vn`mn#wUJV!tspbMq$fdI_a)K*$jmQD
z>%L7IJ<WQ@gVb9_nnJ1|%>|kHC9MN#-TO&>ATz%p&HO#mkLi7xwj-ohNhe4n-*4-d
zk!FFkZX+oMGV=@4y0??=q4xpWc9M3J_L8z7Gry!aL1un0vs4Z;^9$0t*OL~|+eBL{
zsg0B(Z3UV6B|QPsx-XChKxTeHTK8?z=nq)$c#wL_NK;4^q`4q7zoa`sT6ZU@AEb2;
zfHd>-q@(m6qiuk6f^>>B@p4<YoKyqSx+_V&Ag#L@q;<EGcG0_swm#Bc(tgrmkdAkN
zH2j0M?qpIGNb6REwC+OE3VPdVi;+^KjienQt=mUB2-5MsLK*~V-C^an?ikV}kb0-l
zR!*uQ%_g;gv~G;F1*CN!CiR0f^8t{VU(!)}kI^<jIzc)`n)o4Gx13Z1GV@F71!>*Q
zATz(DUG(mut&g;qw4ZbsWagJN{KK~HWKtDK>sEuz{E}AC+fG}Ilp<{;?EsniB^?Br
z`6Ug4wC=DgY~3-WNg(x3qph4&L7Gi!0h#$FZ2_72CG~?e^8t{VU(!)}kI^<jIzc)`
zns}wHTTZG0nfWF4g0${t(AW}rg|?lvi{3r7^^x|H_LB~S%>0suf5g_EOsWED-D=R-
zpzcD_3VPdVi;+^KjienQGry#RATz(DL6FuRHr>`8Lz)Cq?=;%VNfo5oq!y5wU(yzk
znO{;rNHZS*>3E+f9i{geZ3Cneq*J7c6}E0UsRm@`m(&Z=x|=~-cROhpy?bcuBkd*a
zCmjZv`6Ugnv~?$wsz6$|8f4~|w1VDt+G3;>X(MR|$jmS4Ajr%wX%M7!hh1gsjv-9~
zsdpM}<)jMIY*Guz%r9vxNb5dA>IZ4&10XZMq@(m6qiuk6f^>>BafYp1PO1T!`6cy&
zwC-k*nP1W_diT)QN7_r;PdW@T^Gh0jwXHjuR0Yzy)gUv!q!skG(-tG8NE=BzKxTeP
z&wwrpjtoaggCMOtY^JR{hBOJJ-f6UzlPXBFNiCoWL5&#cPLS5!N$Lk_<^v!zzoet|
z9;0o5bb@q>H1VUhZaHZINb7czwt+4V^nDSebsr)<M(-1}^^^9KUL?H^nh@k0Bu$!S
z>&_&#f-Vl?A|S1M3uyzrTWH%xx{tJ*^dv~@9wNOC((#sDW2p?JbuR^J-784f(OW~?
ze9}@<8)+R#>uw``9i(-iB^?22-Cu#U?r%wdqIY<e^^PK4NSZ>L1=70nN$nu5dk1MJ
zNb7zDq;<bVdWznIv>hV7NP3m@N08PXb*-h#L0WeXsTE}A7i8v_w1M6&v~45ZN7_w#
z5@hC=^ae=lj=0WJIY{eX1=70LlNQk1L|ZGVjg%s71!>)#q$fdI_a)K*NbCLqq;=mW
zjlSM`$Ai>cMw&vZAk777-B!{Dkk);W)DP0S2SA$ndD2mOkI^<jIzc)`ns|e)TTYq_
z(z>fiy&$c-8KiZ$lXlU&hqgY_UebQjVUUh@fHeGLw(ew76-et=gS75K(h7RpX^W9k
zq>ZE<Ag$X+ItbG7zCs!VY29HTw{^#mCV|vDjka=91!*>^1*COjqz6D+_i@r8kY@e~
zNXPpN(i`-?N!uXl6zRg*w(sR2ty@L<G)U|Al6Hc$?pHus_gkc==sif=A<~PaS4n>a
zY28tCEPWWHb?Znmkk-8wq;+p6-9zsKwCyDACha9<L0b0+>GvS5JF41JIY{eX1=70L
zlNQk1L|ZGVjg%s71!>)#q-Q`{_Xueaq;-eY*t%m#lR)a7Mq4?lf;5}d0@AuM(w!i!
zyOY!p(#!`yI^O3=N9jFA+W_eV=@e;Vt*u*5ssU-;m84#f*4+%!y4y*+=-oqGA89XX
zKj|<?$2&m!Gf3-})mf?nY29j&)?G+iL2o;4F;a@Ok+cJ(b^A!qfXw`o20>bPSiP+~
zhBOJJ-f6UzlPXBFNi85Vzoac7t@|*kAEcQNfXw`oj?#OKwgJ)!(kar!xwdXO>Ej@+
z+e+#MY2D2rGry!=^zNapkF=MxpL7^x=9lzmkeT0kma0Hnw;E*Tm$ZW3cG_a36lo)A
z2guAXDGSoNuaO2pT6frdTXzg;5=gz%Xe%dGkY<xwKxTePTR>)hN&O(rd;nzTmvofg
zW3&yBPLNKKCN|i*<)mvsTK7g$45W2$1!>*eN%zqE0Bt)-yGeUVS&)wR2<iWTwC=D4
zmdZd{_fnA7y@GTdy*0GWCoLtlk=B8<?l#hwL0Y$;bOfYze+AOIza{;N-r)<acNFPD
z(iGAxkk*|~Y6ofEJ4ic0TK6j;t@|y~Q}iCB?GWij(yOFDg0$|aMV8(N(z;coR*=?>
zfX0@{{kmI78|d9a+cwgDq}`+^L0b0^>6aj_J4h;9Z0lYM8XMHTf^;3dHMGqqEhV*)
z)`86YlD-Tw^GiAcGV=@4y1ym;iQeH$talXYLedn{ERdOBQai}ZFKH*p%r8jmev9-J
zy$5MKM0%0*D(R0PGrvnMO#^A&8%V7nGru6Mdkbj;y<2G8M!Ju*oAe~e%rEH}Nb9~s
zDr>ZLF9n(TC0$2v4Q=yDOG#~{bs#gpq%VWa{F07<%>07P{F44e@9-O~cNFPD(iGAx
zkeOf7r$Jh`m$VaP<`-n<m-H092WdM*dXe-h>5m{YzfG2=fz14pT0v%hL1unQ8|d9a
z+cwgDq}`+^L1unQ$3SL&NoCEp?xi3zzohHvt)Xo`X(_3Vv<_tEm-J=OMZuAwpL7Id
z<`-n<m-HukhcC0<QKSn=Q%JKw6M`D^NuLH?6xe!6J3(fCL1unQPtkjjwnL;BNw1Rr
z2$~So7`5EeG?3Q4fz%4RIEagY%>0rz(7T1UZKV51yGc)iwC*9&F_6}Mhg8;L>s|^n
z^Gmvp-WuBGla`X&Nb5jacN=LBNb5dLIs&>l81Jt@W`0S3qIdXB);o%HA!!O}7D(&P
zCw&@Z=9jb+q;<anGV@D%ir#~?9U{F*dX@A?keT0BOVdDReo3t$ts4QE`6X?jcMEOX
zNcWL;lb!^b`6c}xq;*Gq!csX%>s|%Yy4RBy(Az{?E2)i?B5eg}-JPT-Kw9?&(f~;7
z{sE+Q-zJS-VZGx)>MbKpAyts(g0yZcDGk!P_mcWRTK793&HO#mkLi7xwj-ohNhe4n
zKWXchk!FFkZX+oM(z>^TwC?Ssd+2?Dww<Kiq`jmpNXL7G^d?B_j$LV~9AxGfq;;<+
zEugoFwpLObDMi`}GV@D%0%YcwGypR53(~r8lSY5addGv*TSl5fsvyk;nfWE9L1unQ
zeIPTxAkF+e(vRtVnYJUOS4k&GBR_5HmXT(FwC*BO3}ogPq;+p6-9zsKwCyDACha9<
zL1unQZ-UJHwpl6%nfV22-RnsU=xw5{mDEN`k+y=&{F0sknfWCRfXw`YwC>xa(W|U?
zJV?D|q$#8d(p-?4Us4)m=9kn5GV=@4%-<vZnBJFZJ3@Mubb>T8V(XTXW`NB6l42k;
zzaXu9JLw*JAE0d~X*X#vDGM_5OL`Mz=C|EaImpZ}Nb6otT0n0TZLOp>Qi`+{WagLj
z1jx)UX#iyA7o>IHCXMc}-ti#ymXW5ADoArdW`0R&keOdnAIQuvNHc$r^kaHortJvn
zRniI4$WB|gj5Hmjb?1{}ATz%pt$RD^9(o_3Z6|3rX)h@YGV@FNJxJ@0idrfMnfV22
z-RnsU=xw5{mDEN`k+y=&{F1&6(z=I810XZMAg%j0Y4mFA9S>4(8EFcsf;1Oo=9jbq
zq;(%8^@FtT0gz^Xo^+JnW3&yBPLNKKCa$q{%SkmLt-F%c3(~rqL0We^X&1eFXzL^G
zCG9622I+VQNPh-t-LjaaDv;K#25H@eq!skG(-tG8NE=BzKw7ttlm%(s*GPjPtvf7k
z>y9B!0;zWzZRMm2(ri)-NbAN(TR~d)5mG-$Gamq%`6V5t_ZV#hq!Xl5q=`4%y5*!A
zkeOdnFG%Zd2ATOK?V@)NZGEJ@r2VABATz(Dk+;~oQ%O}Ity>K;^GjMmZ#!)<Qi`;Z
zv;$=3my`vW`6Ug4wC=EktviM^38da>w3U-8NV7>TATz(DEg-G?FsUD;nGb-*mdJg=
z=SfHDJx1FA=>+K%Y2sR2x198Gkk)M_^@6nSX3*H6?sn2HdiT)QN7_r;PdW@T^Gh0@
zv~?$wsz6$|8l-g>l2*{$PFswWB5fq?0GatE9R%rkUm*>GwC=E!tviM^38da>w3U-8
zNV7>TATz(Dtst%Y2&o^WnGb+;yw8)4(tC`y0n!Q5DbmC)TeqB41Jb%HNxdMgyBTEW
zm$ZxCJ+$?a_LBCK4uj16l1AQY>rN$AfwXQl$jmQk1-<RG#YidAM$!(DnP1XDkeOf7
zAV}*DOWV3*NRvS7okm+Zse&|{)B-Z|OS%)Jb$62bL7Mph$jmS4D80vM8z7w^ogz)_
zwsp%%9|vjOR#GoW>uv^_`6cb5cMolSq`jp5q{ARHzob8dE((qeWf@CVAgx;sGV@DX
zL2o;4F;a@Ok+cIeA*j(udIqF*kB|mIT6b8FtviM^38da>w3U-8NV7>Tpb0_U7-<Vg
z>po2C2VES*9RQj6B^{;r7;OWj6Qon5iR*0La#9UQ>#ijAf-Vl~ZU&k8CGDbj4{d#<
zy`=r5!yp~+0BPiHw(e9?6-et=gUtMrR?yo{Ta1(<Z6xggY27~3L6DC371AI`>kjL+
zb;pn<fz&&VwsKMhX*Q_^WagK&1!U%z)DP0k2S8?iNk{2DM%w`C1nCrM;(A-RoKyoc
z^GoUlY2D2rGry!=^zNapkF=MxpL7^x=9e^bgRMK2R0Yzy)gUv!q!skG(-tG8NE=Bz
zKxTePS&)wRHPRqR>khl!)*VBd1XAxb+R8~4q}ikvkeOf7R*=?xgwzkx%m+Ybeo05^
zJx1FA=>+K%Y2qEWZaHZ#Nb9a5^@6nSW{{a*(k^=U(AG!VOWIF53^Mae8vYqucQUC8
zq;;!7W`0R4=xwJhMoN)3l6HX1{F1UDGry!kkk%b`r>#4NGzp~MX|$D-DoC?QEg&<$
zq^%$`zodSUW<CHi^GiBP?=jj2NGC|ANE0{Oy5*z=Ag$X;+6L0PUj%90he(gn`vh(M
zr2V89Nw0%+yo03oZL)Q%NUb2P8v$wETSyz|-9p<o(tV`eq$fdI_Ymm~kdAl6W=rKD
zt$P(n>t0V<KyMRmt)w<minJA^b$61U1ZmxuNCP0P`v;KLeVa6Ti}j8Nske+Yg;YVB
z3(~r+qzxdg`yi<wq;(H~H1qSMqx2r5ZGd!wbc!_bE?c*pv;?GeW29{$t@}lg)_sWd
z7`;!>)=%0`dXe-x$ZS`n@t?JIuO!U}Y26z^TKAKro9Ru{)=Sz*x{vgAkk;)d9R}%m
zPm)G`&enZ5NbA0b^kI5u&{jp7O<GD?4br;3qz6D+_i@r8kdF5!Ag%ig(i`-?N!uXl
z6zRgPw(sR2ty@KE0%_d@X&cDQFUZU<=`nhrpsk;@pY$T>b&#1~(!|f(x|O8)ATz%p
zGry#p=}pttOWH`fkMwnrnP1XBfpokBq*2>!-FJh`{E|LQ?+n_iNV7>xNvlC-en}62
z%>0rLfz14Z%>0txp!ZGM21%z#7v63AUJf$zOKJgW-7eBLkeOeQnP1Xl^gcmbKWRVd
zMbhgaGry$q_t?5ulBTbYC!!_#_vce3C2P)WOZ8+bZi**6Q@3?jbVk=j6RECfx}vvg
zRz-4MBA&dZZA~;ey`u{+=e@r<9jUcl)8n0`V^@`&LZ0(V=B$oJGSe$7hapNW(>v4A
zj?B8CoLJ8rHr>mhIK4C4-m~ViW@!z_f9DPRwmQ7!^v*~oV%p~gF<qmydFO3^bEyj)
z;l&IunVxpt#B<&-8~Tk6n_?PzS@XP)R?V0>Q`UbFQ(`PviC-<#+q=6px}>BOaNe+S
zwwd$q2hfr{5+friDY*&%iBM<3C3le3S-uX7{HbMnCfb`(1Mcrht?Mvz4<X5~ez^TX
z<G?@9GiIu(^{>upEN|vnM$06aKUFvtmPY(Hvc%?@j#ed{&QcG{$sEgSSoUEeT+HWS
z>B8!Amd7Ly2IVY2k~}#U`F7lW7^aIEjXGWL@-3IbQi<`qm|9p)=2()j>^t9&*(rHO
z`<8ymGsd^PB6)Hw^3AvVFomwxhhXWtz_+Y|rSdO)%T`!U=2&Fi?7Ps9$x0q<HZJqO
zN}hN7mj9GIIhKoL0}TG`?7SD2XUF@!s$toLgNw`jNm%CKP~a@LN*)|+oMpS@$+5_{
z+isfZ#~hG6m-v=fB~O`ec}Mc(Sl)vf-t@oxn2*8IILWu%1k2R-_?9#*ujN>_!}7>v
zKjtx5R=wA^ydZhr=Ue_?$&+LG0Jg73ruZ=*hh^1N-?9Rhsh9eewXnRFW7#Bmrui{n
zl05JCEzd}v%Y4hvB~Om!O<4AQz>gV)?Y--A-|{|KDnIC3X25bX$FcyHedT`4N?5u+
z<XhxBa4SFTTmBlBlR1`t$#aDt^Rnc*(zl$DJRk8bW!V2t=2$)s%RU_5-8R+%OIL+&
zxgD0uO5gHj$&+JwTJqrN>+(D=d1m;QUr3&-eanAJo*c_~91r%*^kc4oWz$D}OC2nY
zvwTYwmT}kkmaVY7lw<iOEcaLWG4dU_jo12?=U|z7oo_h;%WFB7e}`q?^?uB79I?7?
z@GT#JrSfCGWezMSb1ZGJJo|A!<_=iypY2<|1k0*9zUA*>nOf~z{tqlCb1Y+Ublg|t
z$6NtRSFLYZ2uo$1Z%M*(GRN`-$y4vg$T!?}&GjvRlsxl%%cVFHpUkl=g=OD-Kc*9w
zRSmvn11#ef_?8D?c`3*8_psc*(2w~!ERBnN%W+u7E%q&?I1jv(W0?ZW{Y(6q>tShJ
z>RWDtWn80gk#DwrDaZ09$#bJ0^Q7cy@-07=Jk7r4KP69&<r18Q?qBA|Tn9_za^LbP
zSjM&ZmOEg1DaW!)^5Ejd?Sls-PpfZv9hRw|@GYe{<Gq$+nF`AzEBu&BSXO<~w^YM2
zb)|1<mOMF@l;ru8AM;ts^J(AmCCSs~TfQZEaxCAMJgfYepGcmFZ~2YnY4<JvEqQV*
z7mq`p4nO9@u&nCzE!V>`HR@Xy!tz><MXm_;t@dL+4@=h?-|`47l`-G)eOONBSdK`Z
zxF7ST<hj|mOvaT(<t@HtE-WW=ED2clCH$ECVCh=xTfQZElD;J?d2%fOCV5hR%t&0b
z$O{O!MSTF4%3FO)JuD}4ET4vDU)qo9g{7<8x7-g)WyZJk!E!RkBHw|#ug8yhUGl8+
zE%IHrmACnpvWt)>$8tR^`+EJDPs7r+-naC^Qn|smJRo^;EPEx-?S9O2lIITJ@+-;n
z8Q=0}$&+Jw&jjST(~r3pmQ5Rd%W_y6H~E%zuuR?TTkeJBwH(VHSoUr4W1fO#(_Oyh
zUtyW^S>JLVt|&`B=Ud(n%d<I_T39x1^<z3<ne%zyvRU$M^DTQMPmblslILz4^J}zb
zC)Y)~;%)1eMcNb5IdiUVtX{sPrMj`9tz}uwqB(P_OJ=WW(~yoxBGDAh^rVv#HmkaI
zVcWu+X0|O^C(+HBNT#QI&YU?bhV+0Vov|GntJ@alL?pVj`;9%(^!kQmCYoLy=?G-Z
zs%}JuoZ#5vRA-MBIlo~^^RntCwe@XnqSDA{NX9eqNFu%=TGG}QU)$BzHa8uOE{eCO
zBkA>XW?JLCXr?ip>ZtC-OYQFNIaSuaC>7~6!POG2;+7{9u-g{;)~C~{^kVdktU(<O
zf|>eTqUr8<D%qS#$CGQkfVy~hS0b{$E*)PNO`9O=ZvI4b8*-?xI@wv1jwCx`LxSp)
zJ!_Y&i+9E&Ce{2%vJ*EZj0Wdko~+JfA|0`4=V=2QW9z%)nA3TU%e(yqi&ATbnq_r)
z(R0(OwI;3Ym>VGhc?xW3Z5lT`qNe{DBazgJDO@zy?}@b4a)otE7T3oMs_yPib;Kd8
z^9<{^uA#Y6Cdmc6QJ$e&PLG_pC6Tq9JVd!{u7X)neq?=8_SN|})%K*jQ)xR01Qs$Q
zZA(oelDwrh)g$|t4R4NSnxd<*`Nx_t>ZRBq)A3H(YgQ+)BS-zsJx|Qio=jIyrooRf
zG8<EA>;|h-UKP({t<W^TZgE3%PgmEFcnNNk1as3^HMOZ^CY?&yZh^Bll}M$BI<Bsh
zX~FtPN0XW6MGbN^;)<=iy6)Pxrs$e@H-_I7?N0TiJ93@Nlj$?Ls}u1^cXLm0XsYgB
zhI>st>D&a^)1#S=SQGBs)%RMt*s(;_ysn<wR2pN!>L22&P9$_yatAbhFuo*mMLR>>
z7-~p_ao-fr#1_RnbJokyS}xfcqMO%aEv{X*zKbisq^a)6;HXwuO?_QMoj-JJdqYiF
zQQCKC>J}W$aYxc*u1&3Nk0&D;99{i{=smY5k??mCBdf8tp`jBSMSOJ}2jwAs5HqwK
zGS&2S7q)sEyiP45n-eL2M^Jl1(~UzawY0}m-A&PTaXBv(@-3}jd?vR!4-7e@XtnBj
zjn%mI>~EBIYITP|fb8Q#%9_0eE2zFMbz8C<n{Z_9P4Ui5Y)GIzss_7cP0#Ap(R6cg
zf;A^TRnZcMf=J@bK{csJy3;>C7@>9RlaaOYj>c};Z@VQRZ#P;Ni>B8`64-PyIH__b
z8)notMcv66&70D3H&%02t&PRI(9^GMJlH94vaL&X+~PZz&Rf)0-zzH>mmE>_w5uf7
zfsLiGqb|BS(v!$^pSGtB@G{tw%i<KSVQ`3xbVb_Z30%%ZIas7?iAQg<HPP8`8n3tJ
z)SqK8$J}VA^km}2sqRR;LylJTFH3c${8i#Y#4|6Q>glpNoJ&q4iAdL?_}X}8XmZFi
zo17%b?|XWup6^cYhir3_kwM8RrMqUm9Ox50IR^@FbShbdByhRo)-Y0;Iyn*Rtz0*V
z!u}kog+t6HKfkWF(X4DaD)(@8HRCK5O||J|5>5oG<7;}-!4VIatnxOLp32he7e<{d
z?Nb*`L^E>MJc~Xuq5>Uo*zMsF!$>-P`a;pVD!Af|LcK^CVr}TwU|vw<tOLEql`FS~
z<;h!;I93hmUKho|E44oNTG*rrPD|dwk3)&b`6}Ph&~1AR6(c)Gv@4=hF+>4Y;%R+#
z(GDD0yKxjbP3MMWNPujVsU&tSyrbx@T+B#x{!ZhxwNKyO7C(Iis?SaLbZ2_jR(IZv
zf8~gnKm4!|9M0qfwV*4yreUr3vdPZ0x*L-Py*M-C<Q>)68XOa$*1s@xt71t?&h#C@
z?lR;BnhC;i>em;TjFyI_!8K%o!>+iNc15|_NxL?Y>gH+?L+(x-Sk@;y=B9Ac%G6=6
z?BJ<Fd^)ArP3@WtI@n!tsIj@$w@BYy3$}rIk+o|hL!$C*vYA2@_TvZ-9Y#$-dqa0q
zPcrGfh7DB83wpm&b0)=8fdn+*RTeJZ7vY>L+X^n(x-cJj#o~98m#THR9_nz%Ug;a$
z2QY`_9ElR&9AA^f6-Ka1dAO8bK{CAAJ;Y^>w9D{1SgsMgao88z`g**fQw}b;PREsi
zUWB?UJrkMh^j?d)NPGS^r=o_=n)L?#%TgOPudbmn9bb#P5{$R2$H=a)t<`PHKMOlw
za1Uar3nx8n-nF#_owDWE)?(LjXNRHvv4IQ?v8wPYstxYBjm-_oPT9j!X_3cCt!rvF
z=d5Pj81b%h#bJ)n1w3-c1!;4x>7++<WSv}h<=OpsnTEOYxeRmrV`#r+si9syshabs
z-%U?#1su>|E(qo&QtgpMfe_gr^+NkhA*Q3h#sj^<ohUi25B1E&XG=_{n)NxG5LS<D
z@y5wLLDE6XlENMxdUaP<!W<s+hkqI;a(bSjGDV5!&QT*n@O=5hz}hvF?5jb+0@mON
zP+*G)1gwk16LR;%^lRwM(NQQQxMazRa%J^^Fm#<ezj%V{5ndz6y3g5$3Jd@{Cw7`B
eUi90me}B-%YbMo1ga#BS1DQ3r+%SnsM*n|(z&kzw

diff --git a/nvapiwrapper/nvapiwrapper.c b/nvapiwrapper/nvapiwrapper.c
deleted file mode 100644
index e705c4a..0000000
--- a/nvapiwrapper/nvapiwrapper.c
+++ /dev/null
@@ -1,41 +0,0 @@
-#include <d3d9.h>
-#include <nvapi.h>
-
-__declspec(dllexport) NvAPI_Status WINAPI NvAPIWrapper_Initialize()
-{
-	return NvAPI_Initialize();
-}
-
-__declspec(dllexport) NvAPI_Status WINAPI NvAPIWrapper_Unload()
-{
-	return NvAPI_Unload();
-}
-
-__declspec(dllexport) NvAPI_Status WINAPI NvAPIWrapper_Stereo_IsEnabled(
-	NvU8 *pIsStereoEnabled)
-{
-	return NvAPI_Stereo_IsEnabled(pIsStereoEnabled);
-}
-
-__declspec(dllexport) NvAPI_Status WINAPI NvAPIWrapper_Stereo_Enable(void)
-{
-	return NvAPI_Stereo_Enable();
-}
-
-__declspec(dllexport) NvAPI_Status WINAPI NvAPIWrapper_Stereo_CreateHandleFromIUnknown(
-	IUnknown *pDevice, StereoHandle *pStereoHandle)
-{
-	return NvAPI_Stereo_CreateHandleFromIUnknown(pDevice, pStereoHandle);
-}
-
-__declspec(dllexport) NvAPI_Status WINAPI NvAPIWrapper_Stereo_IsActivated(
-	StereoHandle stereoHandle, NvU8 *pIsStereoOn)
-{
-	return NvAPI_Stereo_IsActivated(stereoHandle, pIsStereoOn);
-}
-
-__declspec(dllexport) NvAPI_Status WINAPI NvAPIWrapper_Stereo_DestroyHandle(
-	StereoHandle stereoHandle)
-{
-    return NvAPI_Stereo_DestroyHandle(stereoHandle);
-}
\ No newline at end of file
diff --git a/nvapiwrapper/nvapiwrapper.dll b/nvapiwrapper/nvapiwrapper.dll
deleted file mode 100644
index b33032408cb433eca5a4d0dc71319ef1d3956985..0000000000000000000000000000000000000000
GIT binary patch
literal 0
HcmV?d00001

literal 49152
zcmeI5dwf*Yx%W3Ag8_qy6l&grO{D0_@d9(dUxE@EZW68rMMEHi!!3baC@KmXwS-_n
zYAscd+^kK3%B7a3f+YeS5YvLx(o{VHmfBHLxyVbSQ0M(U>zO@k%nWDmIhW6Q|LA-^
zd(E@<`mJZaYwc&Rz4y#sd&b<oO6jgBN+y<QR8d;+POl=7{>Motim%Ck?Hc9Pp1-}J
zrQ7J=-Y_vVtF~Z%P4)dX74r&aR8&<}*A+|;7Sz;N70jwC7&dl7!My6q;Naf9dku=Y
z&N21*+NjdSMd~u>rV~XYkRNo@hq3o#Mc)?rKZ^YAg=dONg#O{8*?7Nm>VTq=qWoy=
z{jah2lj42+tQjHl-L)m9#fmbzn?d<3C;v{h?1YkW!`0n-DatcgQ^;%Ye-ZDwShk6L
zuCOx{#h`Q(E7W&|^611NFLqNhlp<tMiR#7QIlJ^1iV{NUtveLOOT|YN<yCe?Ir%!F
zD9wEoWgR|ufLxnooke+3;#%ZaB<8!=gX@Be>agyS?<2{@LT#mupYSSBlxc%&Dl6(L
z6eZFF1@Nh4VOfJE;Z=l>9?UYO{c04nVnO#Q>#!ueicm7RrnY7V)`_+rfq_0$HepG4
z6_LN1;M{5mKSA4-6Il9U*@7kERir4lCuIL={ug@S<ISktCSM<)Mli~3+oYzBrsAy9
z$TK4qrD1>Oy?ZkgOWWE$?mr?~pWQSjt8`qXU=-EKx_57utRwuz$`$N+Da-MBFNwOz
zpNIP64isOe7B~2o9z+P&e=D?mo01#tmxXjAtx^kmwR{<kMnCR_7KIL?a6J{4M*C%w
z@NpreRH@Hz>P<!CqWuu+xd#lwFMYzn=*Mk%4;4mAyG8qnD*H1Vi!V1kd|9dg*8>Jo
z9fGEQRAqds`m{4fCtZG`weCi#S4omS?)0?K3floo{IfPLgWu4wC;e08suft(;G+Vi
zu4jXfvPxYab<Op$HT8WD7=#9&f50F_uq>@jf4O(xSGR9NNA`hY8q3ulC9m8uy;?3)
z559!5&?EnT%h5PQV{vE0!<|Zfua<w1paFvDq)s%_fId6@9obTBt5;EYp!fn(<#f-c
z;tLI}-5QH8G>y678FTsJ{H944<{ZsF@K|Omnt>Mtb6T^*OS33{`p6ZwjIOp(GZ8Nh
z9erc%sT<tj6Q5ImW6n+keZmv1_1_4s$h>WCyk#3n5Eg~qRP|M&m8WMl^`^qcF_#Y%
zpC#5<tJJRV^VFoX<73{a>k->c#o49U8O9+3kZUaNP`B4NnkIFOM_W;Pc3iBE*s%L^
zn~FQ+MoQw(rG63oeO3M+2MjVgH<BQ1phEDoI>sMt>P>kKe)bmU&ngw{i24NfF&*Qu
z-N1jgG{pK;>?!+y00@}B0G8<gw_h6fx$J)ugbh>(epbu=r@RI~dyDhy>VK}2strl~
zUkC!`zZI6?|JkOS{#EjmAZ(yQ@UvR-Q(l9gy`{&`b#(DtLBRY@Sc1RzJFh<{`AHBq
zP$BqPE%_<0!Oz~(<L5fM_=`Zm{KH@g{%NZ}D3JUl2pgyn{H&Jzl-J;AZ|U)K9bNpR
zLBRZ_umpep>Mehf{3Hk)s1W?Dmi(00;Ad~?@pBzr{AD0u{;9A8|CCRDULyHP5H?UD
z_*pIaDX+oL-qPdeI=c8PLBRYWSc1RD56)O6KMBGHDg-~PWBl`)dQ)D5pS{KTb1}ka
zW3<c~FUHaAuZ*L`9VoqkQXDt9Ue`7xjX(22!2ETv1b@Zf@^DrYJ3HA(g0O)K!Ov>h
z|CHC@XK!(SUE?R$>B^pR{9g<L=3fd+@W1%L=QAWf3Bm>{1V5`KKjk&}*;{)2Tt^rG
zG7vET3Rr^w@cgfRD)~teHc%n>SuOb~uffmW(&Ohky7->~0rRhcCHUXYJoYomPlB+4
z3c=56$xnF=e)g6gKiAR4zYYY<{}L?0Z~kKAE0UiCVFML{pVcvb?7x)P;Ad}fe%<>o
z*X!Dbr2Tgb2$+8xEWvMmdaq6LlOSxMLh!R%_CMt{_}N>WU)TQ2b-J>r+<#j@!2G*m
z3H}}34L_0mBnTU*5d5r`{FK+=XK(58a~)m$`$53`2Vn_*L(@+NN`4ZA4O9qzR!e@$
zYw)wT^!T}sF8(7RVE%Vt3I0`oT$XVBB|+Fgh2Uqk<fps_KYL4$pX=!2e;)+Qe*%`^
zf2!|{LfQW$2pgyn{H%`g<NAg28vN`n&aZj>!unL~DdRr^0_N|4CHQ}6{Q73ePlB+4
z3c=56$xnF=e)guHpY^)=FMxpgJ7Ed_N$>sQe#uXQuz?D}&uSSzl-J;AZ*hKI;}6$K
z)rO?;Q+Y$>&x9rT&0AI*B|izm1}X$Ut7H5NntD@SgP*;{`TODwEf;5K*|^$`#ZvB9
z&fyZTg}H93c2F$QE2%x%AmZ(j3rn=;k?;TDPqIBE2pgyn?P0at9+cN;4||KZN7we?
zI;q-`#GeNO<{tn{@ZbO0*s$a$LD)cr;AeG=AID?LYw)wTIKS@WG1u$bh9v$$AYlGN
zSc3oVkG}SW<R?McK!xCEwdAL~20wdCpP%b#@*6?G{8m_ke_z$f*^-|GVFML{pVg9|
z@*4c?Eq#8jr^)XH0rMBZ68wR!_fM1jBnTU*5d5r`@lSaTe)bmU*A@R<rz?BP{kH@J
z%s(2I;P2i3`D)2eg0O)K!Ov>RPk9Y~_Ld$$*U`m45d_R%221cyY??nx@{=HJphEDo
zTJlp~gP*;n$Io?i@lOK*^H;(W{Fh&^TqpTS5H?UD_*os}$N2>1HTc<EoL}>Ng7vA`
zQ^wC+5HSCISb~4kb+_!2{3Hk)s1W?Dmi(00;Ae08`B|@<e-Q|ne=#h<KlGK~C48Sn
zg0O)K!O!X#KaR(g*WhPwasIT9$6WVHZArO39tRP(XBjNs9^F4kxIQ33*g%D7536JC
zd7!B`<u%%~NqCF5X8_JG@^F697v~pUj%|5gInPM^u84i4YFE<nZ54>PJ<q@r?fLHP
zi~};hNDwwqA=<<0SbOk$2jw-|!`|ZU(KWtu9bNn{fPnee!4mx68$0P?$xni?feOLT
zYROM|4Sx2P9zWO7#or79=HCKK@V~joc%9@YLD)cr;Ageur@RI~drOa>>*(Tt6$H%R
z0!#4s{9tJh$xni?feOLTYROM|4Sx2P9zWO7#or17=HCxX@VmCII4t=|5H?UD_*pIa
zDX+oL-qPdeI=cAVK*0P*U<v*M-ppquKMBGHDg-~PB|qgg_}N=}{9H#De>(`6|9x13
zzirQ^*Cam)!Uie?KdU7_<u&-(TYCIlM;HGo5HNoPmf){`KJsVDPlB+43c=56$xnF=
ze)g6gKiAR4e-;GHe*u=@pEdaR4#`h~uz?D}&*~UIuFoj1!Oz~}{9TS=SN^?&>ve5I
z((&su2$)~l8{?l`>5E8y5`+y@2!2*ee#&d`v$yp5xt=C}7QmQ4Tjf7x_;HcsCqdXi
zh2Uqk<fps_KYL4`pX+Jz_XPp-=fM*3^UmHk6MiovLD)cr;Agdrf68m{v$r_EuJZ@3
z)0I8t`CI`An12u~!N2x<pZ-qvKMBGHDg-~PB|qgg_}N=}{9H#D|E(Zkej_ZwU$yi2
zZIYh^VFML{pVcw``ljBL*WhPwasE7<kM_m+XfDo26ShU)ubhh}-n+u}Q?(`K_HcrT
z+v9~L+Oz!?&pz265`+y@i1x5rZV$?9w1>UL+mq0SE8l;^byBq<X*?PR0_HD)CHMz@
zcYA-yPlB+43c=56$xnF=e)g6gKiAR4UkU=|p9o9v|E1+b0zV1D1}X$Ut0h0>HTc<E
zdi-2R7ynccF#j}If<MRB>t@;iBnTU*5d5r`{FK+=XK(58a~)m$ArLVCTv&qtx`_);
zNq!Q94O9qzR!e@$Yw)wT^!T}sF8(?YF#jT0g1^_h`?g4a5`+y@2!2*ee#&d`v$yp4
zxsERWr66Gb$6*P6)1^BS##0i64O9qzR!e@$Yw)wT^!T}sF8&oDVE$FG1pmYTsQ9t$
ze-eZZR0w`nOMc30@Uyq{__>ZQ{xu+A{uf{g{%8Irvr6)lAZ(yQ@UvR-Q(l9gy`{&`
zb#(E+1On!7h9&sd-8drQ`xFv{4O9qzR!e@$Yw)wT^!T}sF8*yGVE$KO3I6T-N{-0>
zCqdXih2Uqk<fps_KYL4$pX=!2-wguhZ-piJyPv)^T=J73Y@kB$vs&^~UW1>#rN_^8
zbnzbq0rR)P68yt<X5KCNNf0(rA^2G>`6;i#&)(AG=Q_Ih-vI&hx5E<r-zxq?!uO*j
z2pgyn{H&Jzl-J;AZ|U)K9bNn<K*0Q`U<v-e9sMBT_a+jA4O9qzR!e@$Yw)wT^!T}s
zF8&S>F#lOtf`4+a%7pJDNDwwqA^2Gx<Hz+p<u&-(Tby6_^*q<>+J>a_=S~nX|7BQ$
z|2KU;7$W1J1YrXef}hp0|0%D*&)(wvy3YT(PFMDn*Dsm-RQ@bjg8!=1eG<NpAOYqN
zAO%0GB|qgg_}N=}{9H#De=Z2P|NFuc{D*eEJ3;n82{3;EDfn3(<EQxpSgpa&-s1e4
zzn8H-6?@A59{>X8FMuWZmycQhTgguX%pX7sepX9<%4_hmH~svq*UeuD0_MLJmf(Nz
zjKL}SNr3qSNWstQ7(ae5qr3(`dyDg@^?MoDy;56JZVxMnxIIo-qCH>#!QT>&2PD9J
z0;FgUt7UsAuhAa%_MdAH*G;QEMIhq#41*=w^GNW)SLOC00p=GVMSEBsYY)a(%4@WT
zy~W$3dwk`3UE7j0zK#X~^OwRB{C)CQC)^)P0?aQ!3Vv2ge#&d`v$yp5xt=C}83>qv
zDlEZ&@_@l3`=11uUw{<+td8;H_e#oZ@Uyo#zpmp0*Xhcha(}1<0rQ7o3I3gbysM|=
zCjsUcAO%0GW&cxNgP*;{`E|z+*X!Dbr1+T+0_LxSCHNcv?N`SnKM63u04exc9plIN
zM0pK<_7>+)YkcCmUE4t0L475)XEBJlJxgJU_Jm$+N%;Me1YrXeqCKpZ+k^5N?O|{6
z_UPUoT(4_elK7W_fcaOz68sl>?S4;g4-#O$0aEa@T5b=@Yw)wTIDcB(gX?x}gSsu~
zJ*hp<fQZ|(29{_~>yk?|WqU|~`3FeR9#+fkL3xe#u(x=7bZ-x?*R?H4{Odr#{4c>0
z{EvEf{zLMU0P_!!f}hnfevD6)*WhPwaeiIn6W8g=p0fY9fPne8!4mw}I~(7U{3O8q
z1Ek<*wdAL~20wdCkDu%4;%@-~^Y4Zw_|HD^>>9~W0?a=^3Vv3{_;G&@<u&-(Tb%zt
zb$<@~(AA#(Ama8MgeBTzDxCPdY!3-A9|0-a!|GUj@cRzsHQK}8;_XTM_Z_aEsx2ww
z>j;RrJ@3F0?YZ+AbBAmX2{1naDcZy8SbK2%pu9$V*jv0kX^mH0_eyO^*`D`7#O*l&
zOSEV1%ik!M?IA(fK!s=zt7Gk<`3hLA(H`~|Z;$5n66>$jhNST-0s`jmfF<~Ue{kOW
zlAi>auYeT%td{Xbc@2K{7UxepzPP^b_FMoFx2F@9XwQvPuO2GfLjufSK#KOTT5b=@
zYqW>G#oME~Jy@@sU)itnXTlQvuaD2VDEUc%`3p$F&*~UIjvtiQ;Ad}feqF~8u9K<_
zN%52o0`C7@Sc1Q?anv6qKM62j0V()dE&HGH8vN`n&ac`3tWU+Ba(~VP0rL-lCHUX;
zUR5XgNr3qZNWsr)$xnF=e)guHpY^)=2Z4b33t<WV|NCj<S;<cV%vV4Pepbu)p}Yn^
zdyDhyiXX0%strl;V*~;7TVV<Qj@1i)E%`}+`3gwE&uZEKl-J;AZ*hLj_+fo2_LTAC
z1p)IH!4mw|mg~+*eiC550#fj^TJlp~gP*<W=V!fc{t^%{|7ci(zhrIEAjwYx%vV4P
zepbi$@%;wnHTc<EoL~3(H`nXhj->dR2m<CWgC+P6f4X~w<R<~<D<B0wt7ZICUW1>#
z#rbu`KiBEXo-%%>fq?ldVF~`?;upRp`ALBJ3P{1v>KOlhn6H4<8vN`n#*b$XeC5WS
z#GA-j*abSNzvto;nRh-c!Fx;gZw5<V5@3D;Qt+}`@={)dm%ZuWWuX@DB77qAE`}v|
zPj;?MxL=I~n2&%IysVD#;(U$r8ocZ+9v_<H3+uaJQ)q}+Qhz@V0_I-^OYmQCJd$vK
z1qm?!04excE#sT=8vN`n&aW%JxlXD!B=N5T0rNitOYmDw{oFEMNPzhUNWsr)+5eQ+
z;Ad}fe$D=8eJXa^07?8WfPnee!4mwTpRG?gKO+I=8z2Qgt0h0>HTc<^ety>L=5Gc8
z^KXGA_@DhClyH9w2{7LPDfn3}`6;i#&))R&vtBp<s~}+h7FdGcxO-c^j2{wUz5!D3
zvs%VK<u&-(Tby54{BxaDZAglrRuC}%epnp;H{=&feiC550aEa@TJlp~gWoE=rN_^8
zbn&-=fccNW68sz2_LwU9Nr3qVNWsr)$xnF=e)g6gKiAR4-wp!ie;=0MFB_KmuH+{H
z<{KadKdWW@Q(l9gy~X)8#~;?GVoy2#oB{#!M_>v5j*jLxB|ix;-vBB2SuOb~uffmW
z^z*Y`H~(1>F#iQu9REGHjg<T(z<dLw;AgdrAIfX+TZOkczpnk4>!fN!(*AoH1kA7e
zCdNPN7sq^(p9Gk1fI{%ITJlp~gP*;n$Io?i@n->y`Lk92>;C-R(UPA8m~X)Rtd{XZ
zc@2K{7U$QDf7YjBPZ|GxLBRZZutfa)deg(}B|ix;-vBB4pVg9|@*4c?O+P>Db@La1
zfcXc(68v{O-|&&-CjsUgAO%0GW&BWHgP*;{`E|uV*Gbier1-xT1k7)QCHOZi`S2mh
zPXf$0Kni|VOMc30@Uyq{__>ZQekTZ+-wR9d7j3`w`;wmom|uVt{H&Jzl-J;AZ|U)K
z9bNpxK*0PZumt}ve)LF_<R<~<7a#>ct7ZICUW1>##rZY&U)HB$Pr3h=f`Iua!V>(A
zEC1k?{3O8q0;J$)wd{Y&Yw)wT82|FbIVxA4-@$cKwIM0~r-Fd_r@<2ZFBUyNNAi;Z
z^9zuIpVcvb{2oJj4Sx0(@Bg&FFX#HH+LCg6gh0gYnF~v_=U+_0g!xY-z<dLwXb-F9
z_Mp5*d)QmNJ-Wstu9K<_N!z0i1kAq(mf-LHwKuPq+k*s{Z-5m1td{(g*WhPw>G5+N
zUHnTy!2FNH68u9;J{>0cNr3qVNWstQ7(c#mqr3(`dyDhy{=SXtb!|gZ|E~Z6^RI#>
z_#H?4C)_Vi0?ao+3Vv40{-?YKKYNSw>xv())0I7C{I3B4^S=N~@Si(1_Zr#%B*1(F
zq~K?@<fps_KYL4$pX=!2e+dN4-waFeZ!CH0TFFlW%r`&^epX9<%4_hmxAgeAjxPRf
zAYlGiVF~`{7mfVA<R<~<8z2Qgt0h0>HTc<Edi-2R7yoV$Fn=p7!GBf9oeA+ng0O)K
z!Ov>RPk9Y~_Ld$$*U`m)5CqKM221eQJ=KwLK1~A5H$V!0R!e@$Yw)wT^!T}sF8+5w
z!2Ip7IR0yTC!CLx0P_uyf}horpYj^~8-=&@__>ZQ{u3Zz{!_37|M&}|5}w~c0?ao+
z3Vv2ge#&d`v$yp4xsERW4iGT^Sy+O<hwl&gs|59V!z93b1Ek<*wdAL~20wdCkDu%4
z;_n0j^IwJ~_}^~+;Z2gC1ekAt6#T4~{FK+=XK(58a~)m$nPHVb3zp#jY2SgvB|ix;
z-vBB2SuOb~uffmW(&Ohky7+TJ!2RDBmf*i8^Yw)ICjsUgAO%0GWBfGV0IN0l*;|}n
z^LmE$sn}DVKMVi?^B2Gp{2Nb366YIWb=W|K;Ageur@RI~d(+R)dfohmAYlGmVF~_Y
zKi-gVJwpP_H$V!0R!e@$Yw)u-{rs%g&2I$(^E+V){xLs2n=t;90P_owf}hnfe%wz+
zc@2K{7Uxgvelo6mrM9Gury>w>dxpUh?YV2x;)MH0Nr3qUNYNfv$J&GYe<-if9`+V*
zkFN7+u9K=AN!J6TLBRZ_umt~y)*n16$0HJ8egRVOvs%Uz<u&-(Tby5We`b9u_LTi!
z1_I`v3QO>x8uG_aBtHo-zW^!tSsmlY^%&(f_}N>WU-$JG*X!Djr2el20rQ7o3I0fP
ze!_ek5@3D-Qt-1{@>5=epS`8e&-FC<=YxRx>tG4~eht$S?x!RH<`*CZKdWW@Q(l9g
zy~X);#Xr~S%APWQ7K4EKm%<YKufBFZOU4fgFrNS^_*pIcpYj^~>@Ci(JASxc*ES@@
z&oU4&{|Z=w|HtcZNw}UQ0p=4R1wX4LKjk&}*<1SjTu+n#84xi48d!pV)q>(zWdD-@
z^9PWEpVcycD6hfK-s1ea;)m;WWltGD>p;N#FToQ0rse<kP03FJ%pX7sepbi$aXv(O
z4Sx0(=hqxRS)YnMCI1!>F#k4Kg8#F3uRkRDNf0(rA^2G>`=9a}{Om2xudDyLPO3H}
z#eWM3n144c!T<6T`3cW&AOYqNAO%0GB|qgg_}N=}{9H#D|9%iK|3O%Szo27qtL%Rg
zV7>rS@UuF`kK-5RHTc<EjDI<vNxEF$|JQK6u5C!_|05t^{&!$;{5<=U??`?UV158n
z@UvR>Kjk&}KNH^4>wm7(l|5zrzYhZDKLJbd|H*Z6faE6u<^v!FKdWW`Q(l9gy`|s(
zT(4^zlKMXa0_N|4CHUWqEc}V&CjsUIAO%0GW&cxNgP*;{`E~8TT&F90%KpCq0_N|8
zCHM#b;h7$ip9Hx7A1U}*9plINNqG%^_7;yH&GD1<sn}EUD+g5mOjv@y^YEV%?oS~B
z?*B&$epX9<%4_hmH~svq*Ug^|0`C7@Sb~4f>-Q!+Pm%<<{~sy%SuOb~uffmW^z*Y`
zH-8=on128)!Qc0h-IrzjkO24pBLzRJB|qgg_}QC&e%9;e9|QvCFN7ud8zX;9_&%Kk
zxc?t1_*os}$MqxSHTc<EoL|@e%XLz<A!+<Ef`Iw0usHtj{qPpq|0KZu|46~lYROM|
z4gOByEj@m&ql@1Q0_HD*CHO<ru4|M0BnTU*5d5r;@#FYQc@2K{7U$P}{?GNgwjrti
zOF+Q<qhSgD9_F42&!Z**?*B&$epbu=r@RI~dyDhyiXX1il|AM7IS~ZRUj|F?AOB5b
z!ts{`xc?t1_*pIaDX+oL-qPdeI=c9$fq?ldVF~`V(T6Hz{Ez_m|04xIt0h0>HTc<E
zdi-2R7yn!kF#mj5g8x|cZxi@QfcXGO!Ov<L|CHC@XK!(S-SN-$y0#%H{uhCO`4__y
z{6GEu=C8~CCjsUMAO%0GB|qgg_}N?f{9I3y|8Wp7|1wyD|LW&PJ|g)^fcXJP!Ov>R
zPk9Y~_Le?B*VE)*1p?-O2A1GI@lD5W$xi~z4?qfjR!e@$Yw)wT^!d4-CjSc{VE%Qm
z1pn@_uO!@$LITVWKni|V$M|vlrMw0|dyDhy8b7&CSN4?SXEO+xe+w+Z|G`hceTVFS
z5@3D+Qt-1{_CMt{_}N>WU-$mY^}4npY5#o{1kB$8OYnzB&AL_clK}Grkb<AplArP#
z{Om1#ey*p<-wFce-w#Xh&svfHH_1-|%nv{cepbi$@p}g4HTc<EoIkDKGq`ToHc%X?
zucYnK1|n|H5m=%<?&~%zk?kP?<_jQ2dsrQ75AK(vyheN2Tf9AK-!I4Yuhgcb_OyeD
z+w(pw(ViVM|MID94+$`T04dtTYPo$VuhAa%7H>~l+lT93sV%gPlG<|$MBJVTEYY5f
zqYvLD+d~4(CqRn!uv+dfl-FnvdyBV6_x{fHy0#^W|11cY{{k$*?`+spEBQ%)`2<M8
z&uY0nD6hfK-s1deZ4a*7wGHaNl5%@o1`)SMIT&ltyDnqG_tzu{8>kTNVYS>}D6i2T
z_7-nX+WQOFzfzl$woev7xjorxdq!3iB+N%A0p=TUdsrQ74~~bF*JuxWTLxjn{;aP&
zlm5#0`*NLBZAjwp3&+f#2TR1)s<rzD%lIMz<{Kcz_F%Q#KPa!k&)(wvy7v#R*R>5v
z`~@Ij{z0$=|8INNz9sodfcXYU!Ov>h|CHC@XK!(SUFRcQrz?BP{oz&+FuxI&;II1i
zfMb%M1ekAt6#T4~{FK+=XK(58bDb4%-mpKnsko!*FZb@_y*jD?oe(j<7nb0kK4U||
z^V~^*`36YA&uSSzl-J;AZ*hLz@x%4Hwjqgs7zmiZ1eV}`X4}6^k^N5s%r`&^epbi$
z@qH@gHTc<EoL}?%RMvOpR>#yN{!$Py|3p}V-&#@rh2$pz<{KadKdWW@P+o(dy~X);
z#Xr|c)rKVgsUTqfX|M$UH=SoENPZH84O9qzR?GOIyaqpei}UM_AFkK64N3eV5HSB-
zSb~4u%*PYH&n5xp7a#>ct7ZRFUW1>#ErU@1_|J8|%I@hsA3o|cKHK;454$T$Q*?4@
zsiG*+eoMD0xl@|XPLB2~fwl3-TS(fFJaMt!U}-J7Z(qYrN@R#ZQ9_TdQ*tBMz&emQ
z=-IWfGhk1#wBEO`DT<C6H*SKZb@E-V;_P~}%diTc_Q<y?*XPlP^rl=>S!P4<veIO;
z;&b*K#7BJm2?{N(AGdZ>l!k}1yX8Fbb6A!5UtFwjnv%)VMoe-M^3&IP_SIb%iU2>_
z&j}~9l?iu6kD=55ditsZ#o4H<tltm6vor2{qP4E)?EJ`}9*T0>6?y^U&@)I57^s|t
zk?ts(GUbWZoF^WPMx&usBw2wZa*A5jXd|KJy(zAHv+J|)G5x$Kb6x)q*47OO(OV>%
z2_ZhHceFlta<m>dLD1@`X!^$=<1_w4+{<y?hR%$--hllMeelQIP%&zw&Cp~UhR=*1
zLk9r!@di;qn<jd!sU4>Rjm5c*_hvPm&h*@yU2|uHN2&WP+HVnIcCY(5YN3jqyrQvt
zbW$ffjUJ2I$On}jYZ}w(8k1XZa203O{jzZkVi8WWn%Ylqiq>aG`z?kq429%UgoFqV
zOY27J8dve<`mEAezaUP^@4M&Cz1hm_+|a@8=$k*IZ<;=DI^T3}7781SPg&kXpf}nU
zArKmiFMH0_=ek5x)Mqu0IrZ@`skhG785+LKs2{xk1U}I7MqSojlP5%vpl-v%r<9z>
zzYh)8L{|PI8pTTLlBKa#Bk*aY`?6d8AcRA~U8NHuHmth~5fUkfUbw`j>OpIwN1nJy
zAJx774)Pa3IVyF(fj_8@KOf>7)z3fOpALdqO+6dOoG2X^`2zxQ%9MRg!AL{!ltM9m
zp!o8a2%<<&@H7>lirkFP-gm%2jm7FH?;jN5^@hl|QHEf_-)iGuwIgk)H|1V*9FOo~
zM|!lQ5TCGd-J9sD-Y-zvZw;l_KSQZ)6{WrvNN29-*CO6}ZxL_TFB5Nu$Hm)?OU2u5
zi}CitO2an1H5DrxUlQ+`8=LX|RB_hES1JF*iObRG0mE4UcT>74>#1<#OUNBCtU=l{
zQ)xY5ctMn6AES|^@ria+Szjm2_hCl+6;PZ+uwr(%$Umr$W@A4cgq5LFNTU4;k>WR1
z2$cFPX#PZ+5c!VwyA@@n(SAm}y}2*68vzz+rQ&^Uv-^h5QbawSk-T4=YUrdurCqNS
zHK&}eoShYUj_T1?Q3D>4!7)#J#EGYhPn14Ye5#bTfsKZ|=&{nsG}LL>kKlhlT7N2f
zOaywg{sb)ASH8M=-;ay}%07J3AVDa$8N5ZtqZ9t#-oN$l?Ndtb#WtVZ(gN^bQ*u{R
zrzc#S({vTWDkFNN;XtP6%bIiLG;&UEX(bgUS5&Eo|2FYiO=GfJ#@wwaGhN;4GA*t6
zsG;8OZ#?QOEmoBJGnS*jx*9{vOjk)>&NF+P_Nu3D!UxyKE?(m8elX{kL;Fscob$^C
zJuFA>dTLl!9(IfVO%G=`m1KK9uj$!Tmeu`Fo=Y{oZf|HU^c<^+SX!}@f5jd1%>FWz
zy8~PKM;nyf%JtX<l+uQdtO=9v5`khW?zH>{J$|-wBNa6UBj`@DLRfMmH>1-U_GhAB
zCgLCFZ=-dkTv94ZvQXk~DjM`gB>(S68cuYJZHuNcXDb_flbb1kq7ziHi&~C8>cS}6
zDq2o^XiRQtO|B5Vv5vO>jq^o1SEM1NqL0MR+6OZdutKTtDMD-jYz$^{Z*6PiHb-p)
z(ll&PZsXiRxldua<%DehWi%hHj@EZJ6<?0=VDydm$i750Zp=6yF{1T-acJQP4}J0+
zx|sI7$R2!H!~Q%9F>yYUEBd)1*eS-M33u(e^P{3&yRf%JJqPM~Ke4Z_=iiTPq#gBi
zaPm{do!HHasG0SbE%i7)WK*kf!I~R;?<?Lx2VEZNiZ57-&sxrU{$798ugAjk>D(ti
ztIuu<_rCVqit@&Z+^f$v+KB7##~N+)DfgA%^X9&`=#7=A9KCUxNT-UlOr#S<`Z!YR
zwg27Mg&m5L@pDD#i)HjL6vd9^CM?-l&c3QB?_>EjmJL|Ghvh*mQ?X3M;>R)_y1{t=
zCKh^iz|Scx$FQ_vX~wb|%Tg>gSSqoUVJX2<gvE>{Ggg;9aQZnmwwnJeC;v{eG3Y1@
zusFA4`H`YjEv%S7YjEY<xmYLc@^SUSng>Qy)dg#2R?G-uwRq70P6In-N_f?ODy40_
z4WksDw~U`KY{Hjq|9E!7>iRK1svSSP|8<`?)B5S|sr9wNn%b!qRh2ct?@X<%o>4z9
zSXEa$b>Xbq`ii*)wRQECv#JZsMw4-BX-)O);0%-r`WY2-=T03ToExmD4f2}r)Ktu$
zAFLTXzjC??j3FlFi;lija3uDw=BK{M?JmT-7mK>St&7fsQ(LO9mbWLAzqMY;{Qye{
zv7){PVY?~Y6s09$-9@a!Q7Gl>|ED;c-fehIFgSYF^qPvA2bAKBZwKqJC1wn*#1^Zq
zRTOXc(bW}|vGSpcGOBp|oyDUqW)3xL_wsqzQq?ocXVlawO@^89r6~U=qdZtOqq;I!
zSzc9-h}@P@KC5b09U^g_vR&HcLFG5y$}8s8-d`SEG^<WgOx?=M@0dToY{vY$;j`vK
zu3YLyj>{{9)9dfQKUh;9s;-`+C=;NYfzYTbuX|vA5WZ(tmseHH3)aF!t*Q#_1W#p_
z*H-~-j&cvw*e|N9#D{#Vd%0NqX7}>gnlTe5-!a}~G;)h>0Q;gD!TELNAw=!mV2!nW
zM)kaT)m6$TO0j5EX|?zi<&ZKgNR3qU9T{S0Bk#e=;zcu1|Nfw|BXh#sU~s<jaboEm
z)$`_8)CA)qr8RRRI%if@MO~13U-W!yH*AYL>T7DS$EYiRpE;?Dx#$x>Ijg!V)>X=n
zGbaS=u3X%GMD4IxH<n`4!m09sGHh0D#q_zsiJ_Wcd?Vk14O*-Gq`MeDN-=s=*UYP^
zni0ICx}JJh`98(S#91@uh!qO9q2y#oBPwwyNLU-A$La^D?t}+w>w@zp&YBk-S_}9f
zS@Hcu9p661SW08aRk5WR`TbZ<V4=OU6w4|sMOfxzDZrA8C5rNI>{OJISgNr+g=HI-
zx3Q4N45ho0sTh<VJW8sg3Jsj)cP<=SI^r%KXUaz)VrNy%o%LX_$k?T50=gksU492T
ztu9z1!en?&^}G?2s^(Nxf2XR*nOZ+ASX)<9{Qy@evZfXlSJ4K!(npS{9Xg|K)<S%2
z<&{2VL@m3hO!|aL*dHn?;rgGi)IG2w^ENtsir0?=1`0p%di$kupR4xIHr@2Es@?mY
z*Pm1EX{$ddQ0@HHTmGWjQ$G25{4m?&2WPD6`ij5hm8$lO4}3mDwGYq#+NY}hcIL64
zskZrxjjyP-_36Df)!xzF@DtTGH2q|tYOng^viRpd)ptgry8eg8uWwfEN$>sQe$_T_
zSsf3IN521qKdI~Q|7>hnweSAuYhS4LzN(Y6RXect{%NY+yZ!Uksy(r3{wUSH{Ced&
z)!ua7EjS_N*U(pf7w@Z0-9L!)e|L7q0af$8v6CKF?Kk%ruT$-wA1uY!HvFQ0kymZ{
zM|Rbwe>Ycc`loQ!rhnX4ZTk0W)joy)qgHMDXJyr<e<@aN`j=nTrhm&-ZTja~)uw-O
zRc-o5RMn<`7gcTgr%u(Tf4x*~`UgqXrhj8pZTe?J)uw+5RBiglJ=LavuTyRMCpgun
ze^pa$`gbzbrhofVZTjad)uw-<Qf>NIC)K8ZMN)10M<Lawf8<eZ`ga@Erhki3ZTi<0
z)uw+hQEmG757nlB(NJyr7Yfy;e|1o8`iBJ7rhgYuZF)MtYSYv0Rhym?uiEs4b=9V)
zm8&*A^;@;+DcY({Po!3Dda|=>)02`_o1QwX+VtdJ)ut!msy01fR<-Hjt*T8=L{)8i
zvZ!j)lR8zKo_eX;^aM%OrYA9~Ha*o)wdo0gs!dPaQ*C;Boodrl;8dHQsHWQVgfi8p
zr+uk5JvB?U=?PS-O;2-DZF)MAYSUAORGXgCquTVe8`Y*K$EY?vfkn0Hi6*K|PX|$L
zdeVk!(^D%{o1Orn+VnI9)utyCs5Z^=S8bXxui7;GT(xN?w`$YOXw{}!#;Q#-c2%2Z
zys9?M8dYtYg{j&!lTo#4R-kJ4!#qFLrrBz$O*6k#n`Tm}HqA^@ZJObu+B926wQ1Ig
zYSSzZ)u!1Hs!g*CRGaSBS8clUUA5^ha@D3gvQ?YzY*uZ$OIWq(Zd=u+yH{14?gUkB
zx~o#P>Fz|;raS#qo9>!ZZMp+Zwdsy7)uub6RGaQHQf<0hN44oL7uBY_L{yvZvQTZh
zTS2wySANwViQns0n|^gxZTb~gwdog8)uvw-RhxdTQ*HXyOSS3OBh{u~V^o{Inc4n-
z_6)=2rFg09|M~vE+XI>6<GU&J!xNUJDvi2611pRv*5k`-@tsN;Mz6cO;kzHMpm-~4
zYlHKq&wZd^(Y(1;wZ4J%HC67~8KL03irU-e&6-hDU0Xe~?lxR!x+`ku4PIy(Sb!_8
zSu=6HFd1K;;2O_2&@|XM(BHdPL4mifroOgr1g?2?db4mn)T|B8sIQq-_ki$IfS0!>
zxS$@N609t(nY9p?V)qAY<AsUE#fwmtE;dI87Y64R%%#*fu%dQE)xzpI!J2^u^|OY~
zpvzX@z?l_uYl8#*-XU?{U#%SXpP)$kbnlR_uzH8Y8;$DTA!>j6ONW*Y9X4#lo!>4i
ziy8lwJY832VdK7T{EhJ~;}PRAW5oD3;|1gA#;7sNlw;~=y4B=2m6*nwCYh>C-!VO6
zdfc?ew9d5I^mEg%OnXglncgw|yXmi{9CM!8Xf881ntx>8VE(CjtNB;veddVyocWTu
zm!*#-&ysH$Vi|5Jv(#8tSeh-{ExRm-EJrQvmgAN)mLAqT>tJh%HDq02eaO1py4t$N
zy4JeY8n(7u&s(!?g*KDTV;gB3Z!5Ev+p29(+Sb^1*xGCn+d11MTQ7Sbd!9YtKEyuU
zUS_Ycudp}Ux7&Bw5802}+wI5gXY4&3c@DE<v?JtL;CRTf+_BoR#<AA1)e&~IJI*_@
zorO-5)8icJ9Pcc1mOHDRPde8)cR1Ue5$8GQC1)>JA6K3$-!;TF+*RgU=vw7!c5Qd<
zavgFVb+x;WyUw_Jxbxg*_h@&>y}<pDd%1hHdyRXod#gL_Zg-z|XL|}gCXdH6(lg#u
z<|+47d!F>H@$B%lc_N;3o=cuy-ag(uZ@zbkceuCATjO2fZT4>W?(!b;9`&|+k9*H}
zd-(Evc3-J4<Xhl-$hX|L+PB8H*0<Fc_O<)Y`?CFoev{whAL$?OFY}lCtNl;<*Z6n%
z+x!v#IsYYpuRxzbULZd(BrrTs7N`lV2s8(_2X+Mx1&#*V1IGhr0@%3=@I5TzpocNf
zXf}>EhKvi04;hymR~y$D*BZAP!^U>wr-+C`lgZ>UjWmrnm6^&-)utyA4X>CEnj)ri
zrc0(?=01pneDe_VaKu85d4;*zyxqLZe8_y%+-^Q@K4b2INN`&wS{7LzwKQ3tvur>t
zY_;sM9J53$8P)+-r*)`xl=W`wbi_inb&2&^YcrzYgtgP!&33iz8@7Rng(0?pZL%$d
zC|GA}vAtn?%l5AAL&U-vTh#V-dm*A=nthS|QG1j9Ir|30!dCkp`!RdOp5Ykaa5{!M
zMmg?wOh+tKJC-<}bu>HnI^K75I=VTpc7DS-5V0`C8E{T^hMbQ%UvRcK-*CR=eAoFQ
zV&RN4>ioK^(B(%IEOI^SYH~g2+JIQt>e}Nv=8Cw!bmh67?xF5c?z`R75ewDsCGKb4
z&F(|)Q|>I!wVwW-n>}Wa(-ZKF_004v@@(+z_OyFWdQN-3@ML(iyg7&gySKzU-MiSk
z#=G9T+54JzulJz$Fk;}MH_JEB=k=BODtvQ%5BeVSE%U8J4D9qB^nK{N?921t;J?N1
z_TTO=@sC9eEc7q)Z}9K-xBE}}Py4^{X9ThWIfwy!pd>IousE<Lus*Ok@LFJR;9%e|
zV&Edh00wx9fh^-dqt{qwtT4_oK4^T*xXic`F|gBk(D<S8vN6wegXtEN+jP4a70OKu
zP0LIhOuJ3(rjw@ArY}qx<}7m#V!&=LG0!wFHLo$RH*Yq-X5MQ)Xg-V>xM<F@++-=j
zNKj#!V|mc>m}Qw|rDd&Ur{$pKBa4EO;0Eh0R=4$bj0a<_<<^DPW!4SW-53c@T2EWQ
zux8k@Y&o`ko84Aon{Hc-kzl=Tv+Xt8UfV(2VcT)rMO&7Au)V|{vM;bdWM6JyZC_(w
zix>!FEI4n^b`&~H4v%A`W4xoxQH~gR5@W#*N1G$!IOn+J=;iF=%yZ@=28LrSsBx}v
zHaoXFcR3F^k2>3(#}NZPFcz3yqg^4_0@p*X<*wDPHLkUYfiT8`^R8@nq1)v4xJSCj
zyUX0=h=C_D7VL1hxg+j#?n~}oo<5#DPrhe}XE?@!8qW$(vuC?!m*<e@C}QEb=ZvQZ
z#saf<v^V5k;C;xu+`AgFu-3cP8^&00-ka?!^qG7f-$>th#6r2R+V>>Jf*rm#U&MFL
zcgfew-^ZWl&-V}U564(g<6q%#_HXy^@*naaMJycmpYiv=SYQr}4uk>=0uKe22Ua5%
z)&{l)!WawA2b3bj0b(HAScqRJJjRj6@rZ<SW3}-~j08K3Z8$!hGhQ<GGW9X#net6T
zOv5n})R<P7noZkHyG(~nM-d6fO=nC!FcR3!rRI=%f%zfxa`S3L!de^`!Waq8o3ky2
z7L&ze8EF}hNGP{dTb{J6vFxz4VH`MTxn${O?Sn|jw+^umx0YF}5ChHD?bcn^L)N2+
zgyYsT)*iMz+hD{%$hN@tkZrkbH6mfHZL2M8Yqx!2>uYz~huTNk@3v1zBvjj%*q_Bn
zaL9hjp5?gK(cf`1jt5Rhz%kY_)3FGnz&6K0$J>tg9G~EL(CLUea-26gofrk?JC`}1
zc0TXigyTVrbC2_|^CM@cvybamSBYz!>mJu^R}IF3C9ajOmt8Fw1<ty%+}FDMyKlzv
z!08US$GT^_7rCEvzltNlN%v{@7w!yCmL~@hVE2?@6j+KQ!FtbT&ugB&o`aslh=7Zp
zEbq<UVJWx&MQ`qZ%l5xLFg36!@MxeZ@LXU6js{x;djiJ-5gG$Zc?`G)+rPv(&UlY;
zwz0;z$hZV!z{|!K<GVOFNHqeyXlhA00#uoor91`<wv<>xmIaoFEXyscvE|p|C=kZk
zz<Eoywa{v^daNU@<FVz-aTItGX9KTT4_YJEbJk1NUba5i^7%Ll49D3(m2H`=*|y!b
z%XY|i6kGl{jsiV!Hej}oPB{X6itV3j1b7A8Kh+4Z(77tD5#X<`Za5dX!F`L{?Y`Yz
zg6&`KUg%!t{-Jxj`=I-6_j~S7a7NJSj=FO^H{n=trzhlD=6Txlyk`^62wFUQ5Cb21
zIz4^7x8g`J&U=q{HqHnZd6#%sdSCXocz@@O;7D+-ufOkRpV{a11$<+DGkuGE-}5!&
zNbt7rJ>MrdBk1%+eL4P{{7(O!{t%7?Py3(uZ^9Wti+_**u>T`}r@v3&RvZb&1?~yV
z#u>q)z>>hqz{`OaoDp;clxciUm}R`y*xz_F&Ig>vfN`vGCgNbVaSM(EZyVn;equat
z?8I4Oj_D?o({!gPgyX=|rsqwYOgj(@drXH-ADKE$*O&`&92jT5$2=S71B=W{%qz_=
zn_F-`(1GK?wU+*tn=NLG(-N?Zwamm>!D`DE90%UEyl43YvCwIWT5_y6;jG|JoDVFs
zK5c#8y2-l3+G5>fJ#765X9d^be4xZO&UTM&wynmt$hO3`()KdW3Xa-3a2&YS-rs&R
zV!>$-*vHyu;;dk`eT)5|{cZbu_D^s$=(I=eIgXn!5{!4ubu4o{?Reg?2}gq##~#OF
z$43|muEF_0iF2Iu9_MTv4Hh|<I9EDf#z=6~+2PD`UF+)ax*10Urz_wZ>zav?;6;oA
z?XHuq)2=UE8SX51jyvCNM;uIdFUE0Ty?e9!HTPab!eRGu_eGo)4D@($9H{Wj@jU2x
z43V(Xv(~c{Bf&==1;>FKytjDW-rErgW4-0xh2CY}4c^^24xIF!_I}~b@MZaOeEB#t
zEb&eEEyi(Ry>GMcHQ!!D!eQTW-$h@RA6F$f4pjK(_#gB?hDccHU+drLKj{C^f7zcG
zxFK*$z#X_9kuWw;9#|MyhS6X*jsqtHrvqOEl=&P78OAJQjxpb8$A~c9xERNQ^~TM{
z*Nl4+35SixjTdoVIMC$9aiGF9$Mm4-F+{>j(^}I`oELs*x@^ib-(bGQ>^9$yNEmA_
zH!sAPu)(|=$AOdP)8;SC8I~+d4z3UE7!#&j7GpG6Z`o{l&9WDfa2VGI7cE)VfmSa@
zg9_^$>x0(E5D6=BeXtW_!Uu?fJlhSnTWoII?TCc2xIS2jG2unTK)dav?KF-B8TKrD
z4z3UEI4ighF|fwI-oDxXntd-K;V`ZbE@Di$*)c4wtAkgZ2h+Mbu)9msx;ohDIg;|~
zV4-(a%BusjZ*<D5gHI6y|K+QLr5p!6aBW~WmZrQmIB(2Od2O)MbR?~7gDV{uK1B@t
zPaYSpbY{5IaU|t&;lJz5aHso7$}_`-o>eK&4DH_1|CTd@h5l73&kXH>(v)Y07!B~_
zGsi(+91n&XM;Y(NXb{4g;S%Gs#%AO1aAufgy4KX+bhF8fBSHY*8O$^-GCgN{HRYMX
zm97nLwhT*oX7HsYFXh$YUhDg5T^-(TpPJUyVc2mZ<<;RM_>Q0@#ns{MuBj=n4tux@
zQeGYIb-(ZKaCi6g#+AW!p4&Vw&)qmDsK@bOo#&@GFFfk`tEa<r9^Vq=c>CjcVDdU~
zG??U_<$cuqBU~Bmz_$c{_I`>h#Bcg;#96@*91rgBO~f|^kNBSTeeC<X|33c<xE5^o
zzv6$@|C;{|jQ)rH$Nc~9KZPs9&+z>~cU&3f1+EW#D{vdG4~GWE1jgeU@&3TPKy9Eg
zuqyCFoEdBn{1V?691na#aj*{ef8kBRcrXyx29?Gq@J&I9X$-y*co^pZKQw)5$~5;f
z=VIKy%{<h6AFltlnGcvhG5_7%-Ey_%YZ&WGETxvI80|xrDoY)%0_k3&0=QgbJcT&A
b)nqiCz_`(2$}$ha83cXUKVSb7J@EeklpQ6=

-- 
1.7.4.msysgit.0

